@@ -10,15 +10,13 @@
  *   4. Macros implementing Easel debugging output conventions
  *   5. Defined constants
  *   6. Basic support for Easel digitized biosequences
- *   7. Miscellaneous
- *   8. Void declarations of missing augmentations
+ *   7. Using optional compiler attributes
+ *   8. Miscellaneous
  *   9. API declarations of easel.c
- *  10. Copyright and license.
  */
 #ifndef eslEASEL_INCLUDED
 #define eslEASEL_INCLUDED
-
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>		/* for FILE */
@@ -148,12 +146,27 @@
  * need a tmp ptr. All ESL_RALLOC() calls can be safely converted
  * to ESL_REALLOC() calls.
  * 
- * The result of malloc(0) is implementation-defined (either NULL or
- * a ptr that may not be dereferenced), a bit of a hole in the C
- * standard. In Easel, we want to avoid having NULL as a valid
- * non-error result of malloc(), because it confuses static analysis
- * tools when they see dereferences of possibly NULL pointers. We
- * therefore treat malloc(0) as an eslEMEM error.
+ * We don't use zero allocations.  The result of malloc(0) is
+ * implementation-defined (either NULL or a ptr that may not be
+ * dereferenced), a bit of a hole in the C standard. In Easel, we want
+ * to avoid having NULL as a valid non-error result of malloc(),
+ * because it confuses static analysis tools when they see
+ * dereferences of possibly NULL pointers. We therefore treat
+ * malloc(0) as an eslEMEM error.
+ *
+ * The `size` argument is >= 0. It can be either signed or unsigned,
+ * but beware of mixed constructs like `(sizeof(foo) * n)`. `sizeof()`
+ * returns unsigned; (unsigned * signed) first converts the signed
+ * operand to unsigned; if the signed operand is negative, the
+ * conversion adds (UINT_MAX+1) modulo (UINT_MAX+1), and a small
+ * negative signed number becomes a ridiculously large unsigned
+ * one. Even when you know n is positive, a -Walloc-size-larger-than
+ * warning in some gcc versions is very aggressively looking for
+ * problems of this sort, where it may assume that your n could have
+ * any value from INT_MIN to -1, generating a false positive compiler
+ * warning. To suppress this warning we typically use a signed cast,
+ * `(ptrdiff_t) sizeof(foo) * n`.
+ * [2023/0804-h3-gcc-malloc-warning]
  */
 /*::cexcerpt::alloc_macros::begin::*/
 #define ESL_ALLOC(p, size) do {\
@@ -216,10 +229,24 @@
 /* Sometimes a shared function API dictates arguments that a function
  * doesn't use, and we want to silence compiler warnings about this.
  * Putting ESL_UNUSED(x) in the function, for an unused argument <x>,
- * should silence the compiler, and should generate a no-op.
+ * satisfies the compiler while generating a no-op.
  */
 #define ESL_UNUSED(x) (void)(sizeof((x)))
 
+/* Sometimes we need a macro's value as a string constant
+ * instead of a number. For example we might have
+ *    #define eslFOO_DEFAULT 42
+ * and we want to use that default value in an esl_getopts OPTIONS
+ * array, where the default needs to be specified as a string constant
+ * "42" not a number 42.  We can use a C preprocessor trick for this,
+ * using the stringize `#` preprocessor operator. It requires two
+ * steps: one to expand the macro, another to convert the expanded
+ * value to a string constant.  You call ESL_STR(eslFOO_DEFAULT). The
+ * ESL_XSTR() macro is just to make the trick work.
+ */
+#define ESL_XSTR(x) #x
+#define ESL_STR(x)  ESL_XSTR(x)
+
 
 /*****************************************************************
  * 4. Macros implementing Easel's debugging output conventions
@@ -309,7 +336,7 @@
  *****************************************************************/
 
 /* Most of this support is in the alphabet module, but we externalize 
- * some into the easel foundation because ESL_INMAP is used in unaugmented
+ * some into the easel foundation because ESL_INMAP is used in 
  * sqio, msa modules.
  * 
  * A digital sequence residue (ESL_DSQ) is an unsigned 8-bit type
@@ -340,7 +367,47 @@ typedef uint8_t ESL_DSQ;
 
 
 /*****************************************************************
- * 7. Miscellaneous.
+ * 7. Using optional compiler attributes
+ *****************************************************************/
+/* It's convenient to be able to use some optional features of
+ * gcc-like compilers, especially when developing, but we have to be
+ * able to make these features vanish when the compiler doesn't
+ * support them.
+ */
+
+/* ESL_ATTRIBUTE_NORETURN
+ *    Static analyzers (like clang's) may need to be clued in when
+ *    a function cannot return: fatal error handlers, for example.
+ *    gcc-like compilers support the __attribute__((__noreturn__))
+ *    extension on function declarations. Functions that don't return 
+ *    are declared like:
+ *        extern void fatal(char *msg, ...) ESL_ATTRIBUTE_NORETURN;
+ */
+#ifdef  HAVE_FUNC_ATTRIBUTE_NORETURN
+#define ESL_ATTRIBUTE_NORETURN __attribute__((__noreturn__))
+#else
+#define ESL_ATTRIBUTE_NORETURN
+#endif
+
+/* ESL_ATTRIBUTE_FORMAT
+ *    For printf()-like functions with a variable number of arguments
+ *    corresponding to a format string, a compiler is generally unable
+ *    to check that the args match the format. gcc-like compilers
+ *    allow declaring a "format" attribute to enable typechecking of
+ *    printf-like functions. The arguments are printf, <string_idx>,
+ *    <first-to-check>. For example:
+ *      extern void my_printf(FILE *fp, char *s, ...) ESL_ATTRIBUTE_FORMAT(printf, 2, 3);
+ */
+#ifdef HAVE_FUNC_ATTRIBUTE_FORMAT
+#define ESL_ATTRIBUTE_FORMAT(type,idx,first) __attribute__((format(type,idx,first)))
+#else
+#define ESL_ATTRIBUTE_FORMAT(type,idx,first)
+#endif
+
+
+
+/*****************************************************************
+ * 8. Miscellaneous.
  *****************************************************************/
 /* A placeholder for helping w/ portability of filenames/paths.
  * I think, but have not tested, that:
@@ -364,9 +431,10 @@ typedef uint8_t ESL_DSQ;
 #define ESL_MIN(a,b)          (((a)<(b))?(a):(b))
 #define ESL_MAX(a,b)          (((a)>(b))?(a):(b))
 
-static inline float esl_log (double x) { return (x == 0.0 ? -eslINFINITY : log(x));  } /* avoid fp exceptions; log(0) = -inf is fine */
-static inline float esl_logf(float x)  { return (x == 0.0 ? -eslINFINITY : logf(x)); }
-static inline float esl_log2f(float x) { return (x == 0.0 ? -eslINFINITY : eslCONST_LOG2R * logf(x)); }
+static inline float esl_log  (double x) { return (x == 0.0 ? -eslINFINITY : log(x));  } /* avoid fp exceptions; log(0) = -inf is fine */
+static inline float esl_log2 (double x) { return (x == 0.0 ? -eslINFINITY : log2(x)); } 
+static inline float esl_logf (float x)  { return (x == 0.0 ? -eslINFINITY : logf(x)); }
+static inline float esl_log2f(float x)  { return (x == 0.0 ? -eslINFINITY : log2f(x)); }
 
 /* Typedef: <esl_pos_t> 
  * 
@@ -385,36 +453,6 @@ static inline float esl_log2f(float x) { return (x == 0.0 ? -eslINFINITY : eslCO
 typedef int64_t esl_pos_t;
 
 
-/* ESL_ANALYZER_NORETURN
- *    adds some optional support for clang static analysis. 
- *    The static analyzer sometimes needs to be clued in when a
- *    function cannot return: fatal error handlers, for example.
- *    clang, gcc, and other gcc-like compilers support the __attribute__
- *    extension on function declarations. We detect this support
- *    at compile-time in the configure script. Functions that
- *    don't return are declared like:
- *       extern void fatal(char *msg, ...) ESL_ANALYZER_NORETURN;    
- */
-#ifndef ESL_ANALYZER_NORETURN
-#ifdef  HAVE_FUNC_ATTRIBUTE_NORETURN
-#define ESL_ANALYZER_NORETURN __attribute__((__noreturn__))
-#else
-#define ESL_ANALYZER_NORETURN
-#endif
-#endif
-
-
-
-
-/*****************************************************************
- * 8. Void declarations of missing augmentations
- *****************************************************************/
-#ifndef eslAUGMENT_ALPHABET
-typedef void ESL_ALPHABET;
-#endif
-#ifndef eslAUGMENT_KEYHASH
-typedef void ESL_KEYHASH;
-#endif
 
 /*****************************************************************
  * 9. The API declarations for easel.c
@@ -427,19 +465,23 @@ extern void esl_exception(int errcode, int use_errno, char *sourcefile, int sour
 extern void esl_exception_SetHandler(esl_exception_handler_f);
 extern void esl_exception_ResetDefaultHandler(void);
 extern void esl_nonfatal_handler(int errcode, int use_errno, char *sourcefile, int sourceline, char *format, va_list argp);
-extern void esl_fatal(const char *format, ...) ESL_ANALYZER_NORETURN;
+extern void esl_fatal(const char *format, ...) ESL_ATTRIBUTE_NORETURN;
 
 /* 2. Memory allocation/deallocation conventions. */
+extern int  esl_resize(int n, int a, int r);
+extern void esl_free(void *p);
 extern void esl_Free2D(void  **p, int dim1);
 extern void esl_Free3D(void ***p, int dim1, int dim2);
 
 /* 3. Standard banner for Easel miniapplications. */
-extern int  esl_banner    (FILE *fp, char *progname, char *banner);
-extern int  esl_usage     (FILE *fp, char *progname, char *usage);
+extern int  esl_banner    (FILE *fp, const char *progname, char *banner);
+extern int  esl_usage     (FILE *fp, const char *progname, char *usage);
 extern int  esl_dataheader(FILE *fp, ...);
 
 /* 4. Improved replacements for some C library functions */
 extern int  esl_fgets(char **buf, int *n, FILE *fp);
+extern int  esl_fprintf(FILE *fp, const char *format, ...);
+extern int  esl_printf(const char *format, ...);
 extern int  esl_strdup(const char *s, int64_t n, char **ret_dup);
 extern int  esl_strcat(char **dest, int64_t ldest, const char *src, int64_t lsrc);
 extern int  esl_strmapcat        (const ESL_DSQ *inmap, char **dest, int64_t *ldest, const char *src, esl_pos_t lsrc);
@@ -459,6 +501,10 @@ extern int  esl_strcasecmp(const char *s1, const char *s2);
 #define strcasecmp esl_strcasecmp
 #endif
 #endif
+#ifndef HAVE_STRSEP
+extern char *esl_strsep(char **stringp, const char *delim);
+#define strsep     esl_strsep
+#endif
 
 /* 6. Additional string functions, esl_str*() */
 extern int     esl_strchop(char *s, int64_t n);
@@ -481,24 +527,15 @@ extern int  esl_tmpfile_named(char *basename6X, FILE **ret_fp);
 extern int  esl_getcwd(char **ret_cwd);
 
 /* 8. Typed comparison routines. */
-extern int  esl_DCompare   (double a, double b, double tol);
-extern int  esl_FCompare   (float  a, float  b, float  tol);
-extern int  esl_DCompareAbs(double a, double b, double tol);
-extern int  esl_FCompareAbs(float  a, float  b, float  tol);
+extern int  esl_DCompare(double x0, double x, double r_tol, double a_tol);
+extern int  esl_FCompare(float  x0, float  x, float  r_tol, float  a_tol);
 extern int  esl_CCompare(char *s1, char *s2);
+extern int  esl_DCompare_old(double a,  double b, double tol);
+extern int  esl_FCompare_old(float  a,  float  b, float  tol);
+
+/* 9. Other miscellaneous functions */
+extern uint32_t esl_mix3(uint32_t a, uint32_t b, uint32_t c);
 
 #endif /*eslEASEL_INCLUDED*/
 
 
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- * 
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
