@@ -4,9 +4,9 @@
  */
 #ifndef eslCLUSTER_INCLUDED
 #define eslCLUSTER_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
-extern int esl_cluster_SingleLinkage(void *base, size_t n, size_t size, 
-				     int (*linkfunc)(const void *, const void *, const void *, int *), void *param,
+extern int esl_cluster_SingleLinkage(const void *base, size_t n, size_t size, 
+				     int (*linkfunc)(const void *, const void *, const void *, int *), const void *param,
 				     int *workspace, int *assignments, int *ret_C);
 #endif /*eslCLUSTER_INCLUDED*/
