@@ -6,9 +6,8 @@
  *    3. Unit tests.
  *    4. Test driver.
  *    5. Examples.
- *    6. Copyright/license information.
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -127,10 +126,8 @@ esl_fileparser_Create(FILE *fp)
 /* Function:  esl_fileparser_CreateMapped()
  * Incept:    MSF, Mon Aug 16 2010 [Janelia]
  *
- * Purpose:   Sets up a memory buffer to be parsed with the
- *            file parser routines.Take an open file <fp>, and transform it to
- *            a fileparser object -- preparing to parse it
- *            one whitespace-delimited field at a time.
+ * Purpose:   Sets up a memory buffer to be parsed with the file parser
+ *            routines.
  *
  * Args:      fp  - open FILE to parse
  *
@@ -142,7 +139,7 @@ esl_fileparser_Create(FILE *fp)
  * Xref:      STL8 p.56.
  */
 ESL_FILEPARSER *
-esl_fileparser_CreateMapped(void *buffer, int size)
+esl_fileparser_CreateMapped(const void *buffer, int size)
 {
   ESL_FILEPARSER *efp = NULL;
 
@@ -233,8 +230,7 @@ esl_fileparser_GetToken(ESL_FILEPARSER *efp, char **opt_tok, int *opt_toklen)
 	if (fcode != eslOK) return fcode;
       } 
     else if (tokcode == eslOK) goodtok = TRUE;
-    else 
-      { sprintf(efp->errbuf, "esl_strtok() failed"); return tokcode;}
+    else ESL_FAIL(tokcode, efp->errbuf, "esl_strtok() failed");
   } while (! goodtok);
 
   if (opt_tok)    *opt_tok    = tok;
@@ -275,8 +271,8 @@ esl_fileparser_NextLine(ESL_FILEPARSER *efp)
 
   while ((status = nextline(efp)) == eslOK) 
     {
-      while (efp->s != '\0' && isspace(*(efp->s))) efp->s++;
-      if    (*efp->s != '\0' && *efp->s != efp->commentchar) break;
+      while (*(efp->s) != '\0' && isspace(*(efp->s))) efp->s++;
+      if    (*(efp->s) != '\0' && *efp->s != efp->commentchar) break;
     } 
   if (status == eslEOF) return status;
   if (status != eslOK)  ESL_FAIL(status, efp->errbuf, "nextline() failed");
@@ -356,9 +352,9 @@ esl_fileparser_NextLinePeeked(ESL_FILEPARSER *efp, char *prefix, int plen)
   memcpy(efp->buf, prefix, plen);
   efp->s = efp->buf;
 
-  while (efp->s != '\0' && isspace(*(efp->s))) efp->s++;
-  if    (*efp->s != '\0' && *efp->s != efp->commentchar) return eslOK;
-  else                                                   return esl_fileparser_NextLine(efp);
+  while (*(efp->s) != '\0' && isspace(*(efp->s))) efp->s++;
+  if    (*(efp->s) != '\0' && *efp->s != efp->commentchar) return eslOK;
+  else                                                     return esl_fileparser_NextLine(efp);
 
  ERROR:
   return status;
@@ -530,7 +526,7 @@ nextline(ESL_FILEPARSER *efp)
   if (efp->is_buffer) {
     int   len;
     int   end;
-    char *ptr;
+    const char *ptr;
 
     if (efp->mem_pos >= efp->mem_size) return eslEOF;
 
@@ -551,7 +547,7 @@ nextline(ESL_FILEPARSER *efp)
 
   } else {
     if ((status = esl_fgets(&(efp->buf), &(efp->buflen), efp->fp)) != eslOK) 
-      { sprintf(efp->errbuf, "esl_fgets() failed"); return status;}
+      ESL_FAIL(status, efp->errbuf, "esl_fgets() failed");
   }
   efp->s = efp->buf;
   efp->linenumber++;
@@ -622,7 +618,7 @@ utest_GetTokenOnLine(char *filename)
       while ((status = esl_fileparser_GetTokenOnLine(efp, &tok, &toklen)) == eslOK)
 	{
 	  ntok++;
-	  sprintf(expect, "token%d", ntok);
+	  snprintf(expect, 32, "token%d", ntok);  // 32 is from the static allocation of expect[32]
 	  if (toklen != 6)               esl_fatal("bad token length for %s", tok);
 	  if (strcmp(expect, tok) != 0)  esl_fatal("bad token %s", tok);
 	}
@@ -793,19 +789,3 @@ main(int argc, char **argv)
 
 
 
-
-
-
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- * 
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
-
