@@ -5,7 +5,7 @@
  */
 #ifndef eslGEV_INCLUDED
 #define eslGEV_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include "esl_random.h"
 
