@@ -1,11 +1,10 @@
 /* Collection and display of score histograms.
  * 
  * SRE, Fri Jul  1 13:22:45 2005 [St. Louis]
- * SVN $Id$
- * SVN $URL$
  */
 #ifndef eslHISTOGRAM_INCLUDED
 #define eslHISTOGRAM_INCLUDED
+#include <esl_config.h>
 
 #include <math.h>   /* floor() is in one of the macros */
 
@@ -125,12 +124,3 @@ extern int esl_histogram_Goodness(ESL_HISTOGRAM *h, int nfitted,
 
 
 #endif /*eslHISTOGRAM_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
