@@ -6,12 +6,11 @@
  *   3. Unit tests.
  *   4. Test driver.
  *   5. Example.
- *   6. Copyright and license information.
  *   
  * This module is responsible for i/o of both eslMSAFILE_CLUSTAL and
  * eslMSAFILE_CLUSTALLIKE alignment formats.
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -19,18 +18,15 @@
 #include <ctype.h>
 
 #include "easel.h"
-#ifdef eslAUGMENT_ALPHABET
 #include "esl_alphabet.h"
-#endif
 #include "esl_mem.h"
 #include "esl_msa.h"
 #include "esl_msafile.h"
+
 #include "esl_msafile_clustal.h"
 
 static int make_text_consensus_line(const ESL_MSA *msa, char **ret_consline);
-#ifdef eslAUGMENT_ALPHABET
 static int make_digital_consensus_line(const ESL_MSA *msa, char **ret_consline);
-#endif
 
 /*****************************************************************
  *# 1. API for reading/writing Clustal and Clustal-like formats
@@ -49,14 +45,13 @@ esl_msafile_clustal_SetInmap(ESL_MSAFILE *afp)
 {
   int sym;
 
-#ifdef eslAUGMENT_ALPHABET
   if (afp->abc)
     {
       for (sym = 0; sym < 128; sym++) 
 	afp->inmap[sym] = afp->abc->inmap[sym];
       afp->inmap[0] = esl_abc_XGetUnknown(afp->abc);
     }
-#endif
+
   if (! afp->abc)
     {
       for (sym = 1; sym < 128; sym++) 
@@ -212,19 +207,21 @@ esl_msafile_clustal_Read(ESL_MSAFILE *afp, ESL_MSA **ret_msa)
 
   afp->errmsg[0] = '\0';
   
-#ifdef eslAUGMENT_ALPHABET
   if (afp->abc   &&  (msa = esl_msa_CreateDigital(afp->abc, 16, -1)) == NULL) { status = eslEMEM; goto ERROR; }
-#endif
   if (! afp->abc &&  (msa = esl_msa_Create(                 16, -1)) == NULL) { status = eslEMEM; goto ERROR; }
 
   /* skip leading blank lines in file */
   while ( (status = esl_msafile_GetLine(afp, &p, &n)) == eslOK  && esl_memspn(afp->line, afp->n, " \t") == afp->n) ;
   if      (status != eslOK)  goto ERROR; /* includes normal EOF */
     
-  /* That first line says something like: "CLUSTAL W (1.83) multiple sequence alignment" */
+  /* That first line says something like:
+   *   "CLUSTAL W (1.83) multiple sequence alignment" 
+   *   "CLUSTAL format alignment by MAFFT FFT-NS-i (v7.309)"
+   *   "MUSCLE (3.7) multiple sequence alignment"
+   */
   if (esl_memtok(&p, &n, " \t", &tok, &ntok) != eslOK)                             ESL_XFAIL(eslEFORMAT, afp->errmsg, "missing CLUSTAL header");
   if (afp->format == eslMSAFILE_CLUSTAL && ! esl_memstrpfx(tok, ntok, "CLUSTAL"))  ESL_XFAIL(eslEFORMAT, afp->errmsg, "missing CLUSTAL header"); 
-  if (! esl_memstrcontains(p, n, "multiple sequence alignment"))                   ESL_XFAIL(eslEFORMAT, afp->errmsg, "missing CLUSTAL header");
+  if (! esl_memstrcontains(p, n, "alignment"))                                     ESL_XFAIL(eslEFORMAT, afp->errmsg, "missing CLUSTAL header");
 
   /* skip blank lines again */
   do {
@@ -237,11 +234,15 @@ esl_msafile_clustal_Read(ESL_MSAFILE *afp, ESL_MSA **ret_msa)
   do { 		/* afp->line, afp->n is now the first line of a block... */
     idx = 0;
     do {
-      for (pos = 0;     pos < n; pos++) if (! isspace(p[pos])) break;  name_start = pos; 
-      for (pos = pos+1; pos < n; pos++) if (  isspace(p[pos])) break;  name_len   = pos - name_start;
-      for (pos = pos+1; pos < n; pos++) if (! isspace(p[pos])) break;  seq_start  = pos;      
+      for (pos = 0;     pos < n; pos++) if (! isspace(p[pos])) break;  
+      name_start = pos; 
+      for (pos = pos+1; pos < n; pos++) if (  isspace(p[pos])) break;  
+      name_len   = pos - name_start;
+      for (pos = pos+1; pos < n; pos++) if (! isspace(p[pos])) break;  
+      seq_start  = pos;      
       if (pos >= n) ESL_XFAIL(eslEFORMAT, afp->errmsg, "invalid alignment line");
-      for (pos = pos+1; pos < n; pos++) if (  isspace(p[pos])) break;  seq_len    = pos - seq_start; /* expect one block; ignore trailing stuff, inc. optional coords */
+      for (pos = pos+1; pos < n; pos++) if (  isspace(p[pos])) break;  
+      seq_len    = pos - seq_start; /* expect one block; ignore trailing stuff, inc. optional coords */
 
       if (idx == 0) {
 	block_seq_start = seq_start;
@@ -264,9 +265,7 @@ esl_msafile_clustal_Read(ESL_MSAFILE *afp, ESL_MSA **ret_msa)
 
       /* Append the sequence. */
       cur_alen = alen;
-#ifdef eslAUGMENT_ALPHABET
       if (msa->abc)    { status = esl_abc_dsqcat(afp->inmap, &(msa->ax[idx]),   &(cur_alen), p+seq_start, seq_len); }
-#endif
       if (! msa->abc)  { status = esl_strmapcat (afp->inmap, &(msa->aseq[idx]), &(cur_alen), p+seq_start, seq_len); }
       if      (status == eslEINVAL)    ESL_XFAIL(eslEFORMAT, afp->errmsg, "one or more invalid sequence characters");
       else if (status != eslOK)        goto ERROR;
@@ -360,11 +359,8 @@ esl_msafile_clustal_Write(FILE *fp, const ESL_MSA *msa, int fmt)
     }
 
   /* Make a CLUSTAL-like consensus line */
-#ifdef eslAUGMENT_ALPHABET 
-  //  if (msa->abc &&  (status = make_digital_consensus_line(msa, &consline)) != eslOK) goto ERROR;
-  if (msa->abc &&  (status = make_digital_consensus_line(msa, &consline)) != eslOK) goto ERROR;
-#endif
-  if (! msa->abc && (status = make_text_consensus_line(msa, &consline))   != eslOK) goto ERROR;
+  if (  msa->abc && (status = make_digital_consensus_line(msa, &consline)) != eslOK) goto ERROR;
+  if (! msa->abc && (status = make_text_consensus_line   (msa, &consline)) != eslOK) goto ERROR;
 
   /* The magic header */
   if      (fmt == eslMSAFILE_CLUSTAL)     { if (fprintf(fp, "CLUSTAL 2.1 multiple sequence alignment\n")               < 0) ESL_XEXCEPTION_SYS(eslEWRITE, "clustal msa write failed");  }
@@ -376,9 +372,7 @@ esl_msafile_clustal_Write(FILE *fp, const ESL_MSA *msa, int fmt)
       if (fprintf(fp, "\n") < 0) ESL_XEXCEPTION_SYS(eslEWRITE, "clustal msa write failed"); 
       for (i = 0; i < msa->nseq; i++)
 	{
-#ifdef eslAUGMENT_ALPHABET 
 	  if (msa->abc)   esl_abc_TextizeN(msa->abc, msa->ax[i]+apos+1, cpl, buf);
-#endif
 	  if (! msa->abc) strncpy(buf, msa->aseq[i]+apos, cpl);
 	  if (fprintf(fp, "%-*s %s\n", maxnamelen, msa->sqname[i], buf) < 0) ESL_XEXCEPTION_SYS(eslEWRITE, "clustal msa write failed"); 
 	}
@@ -509,7 +503,6 @@ make_text_consensus_line(const ESL_MSA *msa, char **ret_consline)
  * Exactly the same as make_text_consensus_line(), except for
  * digital mode <msa>.
  */
-#ifdef eslAUGMENT_ALPHABET
 static int
 matches_group_digital(ESL_ALPHABET *abc, uint32_t v, char *group)
 {
@@ -594,9 +587,6 @@ make_digital_consensus_line(const ESL_MSA *msa, char **ret_consline)
   *ret_consline = NULL;
   return eslOK;
 }
-
-
-#endif /*eslAUGMENT_ALPHABET*/
 /*-------------- end, internal clustal routines -----------------*/
 
 
@@ -883,7 +873,7 @@ read_test_msas_text(char *alnfile, char *stkfile)
  *  (gcov): gcc -g -Wall -fprofile-arcs -ftest-coverage -I. -L. -o esl_msafile_clustal_utest -DeslMSAFILE_CLUSTAL_TESTDRIVE esl_msafile_clustal.c -leasel -lm
  * run:     ./esl_msafile_clustal_utest
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdio.h>
 
@@ -1070,12 +1060,3 @@ main(int argc, char **argv)
 #endif /*eslMSAFILE_CLUSTAL_EXAMPLE2*/
 /*--------------------- end of example --------------------------*/
 
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
