@@ -4,7 +4,7 @@
  */
 #ifndef eslMSASHUFFLE_INCLUDED
 #define eslMSASHUFFLE_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include "esl_alphabet.h"
 #include "esl_random.h"
