@@ -2,7 +2,9 @@
  */
 #ifndef eslRANDOM_INCLUDED
 #define eslRANDOM_INCLUDED
+#include <esl_config.h>
 
+#include <stdio.h>
 #include <stdint.h>
 
 #define eslRND_FAST     0
@@ -16,16 +18,12 @@ typedef struct {
   uint32_t seed;		/* seed used to init the RNG                   */
 } ESL_RANDOMNESS;
 
-/* esl_rnd_Roll(a) chooses a uniformly distributed integer
- * in the range 0..a-1, given an initialized ESL_RANDOMNESS r.
- */
-#define esl_rnd_Roll(r, a)    ((int) (esl_random(r) * (a)))
 
 /* 1. The ESL_RANDOMNESS object.
  */
 extern ESL_RANDOMNESS *esl_randomness_Create    (uint32_t seed);
-extern ESL_RANDOMNESS *esl_randomness_CreateFast(uint32_t seed);
-extern ESL_RANDOMNESS *esl_randomness_CreateTimeseeded(void); /* DEPRECATED */
+extern ESL_RANDOMNESS *esl_randomness_CreateFast(uint32_t seed);       // DEPRECATED. Use esl_randomness_Create.  The Knuth LCG used to have a speed advantage for us, but MT is fast.
+extern ESL_RANDOMNESS *esl_randomness_CreateTimeseeded(void);          // DEPRECATED. Use esl_randomness_Create(0)
 extern void            esl_randomness_Destroy(ESL_RANDOMNESS *r);
 extern int             esl_randomness_Init(ESL_RANDOMNESS *r, uint32_t seed);
 extern uint32_t        esl_randomness_GetSeed(const ESL_RANDOMNESS *r);
@@ -34,6 +32,8 @@ extern uint32_t        esl_randomness_GetSeed(const ESL_RANDOMNESS *r);
  */
 extern double   esl_random       (ESL_RANDOMNESS *r);
 extern uint32_t esl_random_uint32(ESL_RANDOMNESS *r);
+extern int      esl_rnd_Roll     (ESL_RANDOMNESS *r, int n);
+extern uint32_t esl_rnd_mix3(uint32_t a, uint32_t b, uint32_t c);
 
 /* 3. Debugging/development tools.
  */
@@ -44,8 +44,8 @@ extern int esl_randomness_Dump(FILE *fp, ESL_RANDOMNESS *r);
 extern double esl_rnd_UniformPositive(ESL_RANDOMNESS *r);
 extern double esl_rnd_Gaussian (ESL_RANDOMNESS *rng, double mean, double stddev);
 extern double esl_rnd_Gamma    (ESL_RANDOMNESS *rng, double a);
-extern void   esl_rnd_Dirichlet(ESL_RANDOMNESS *rng, const double *alpha, int K, double *p);
-extern void   esl_rnd_mem      (ESL_RANDOMNESS *rng, void *buf, int n);
+extern int    esl_rnd_Dirichlet(ESL_RANDOMNESS *rng, const double *alpha, int K, double *p);  // Pass alpha=NULL if you just want a uniform draw.
+extern int    esl_rnd_Deal     (ESL_RANDOMNESS *rng, int m, int n, int *deal);
 
 /* 5. Multinomial sampling from discrete probability n-vectors.
  */
@@ -54,14 +54,9 @@ extern int    esl_rnd_FChoose   (ESL_RANDOMNESS *r, const float  *p,   int N);
 extern int    esl_rnd_DChooseCDF(ESL_RANDOMNESS *r, const double *cdf, int N);
 extern int    esl_rnd_FChooseCDF(ESL_RANDOMNESS *r, const float  *cdf, int N);
 
+/* 6. Random data generators (unit testing, etc.)
+ */
+extern int    esl_rnd_mem        (ESL_RANDOMNESS *rng, void *buf, int n);
+extern int    esl_rnd_floatstring(ESL_RANDOMNESS *rng, char *s);
 
 #endif /*eslRANDOM_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
