@@ -2,6 +2,7 @@
  */
 #ifndef eslRANDOMSEQ_INCLUDED
 #define eslRANDOMSEQ_INCLUDED
+#include <esl_config.h>
 
 #include "esl_alphabet.h"
 #include "esl_random.h"
@@ -56,16 +57,4 @@ extern int esl_rsq_XMarkov0  (ESL_RANDOMNESS *r, const ESL_DSQ *dsq, int L, int
 extern int esl_rsq_XMarkov1  (ESL_RANDOMNESS *r, const ESL_DSQ *dsq, int L, int K, ESL_DSQ *markoved);
 
 #endif /*eslRANDOMSEQ_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
 
