@@ -12,7 +12,7 @@
  */    
 #ifndef eslREGEXP_INCLUDED
 #define eslREGEXP_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
 /* ESL_REGEXP_NSUB specifies the maximum number of () expressions
  * in a regexp. The whole regexp counts as one, so 16 allows for 
@@ -52,19 +52,19 @@ typedef struct {
 
 /* Declaration of functions in the API
  */
-
 extern ESL_REGEXP *esl_regexp_Create(void);
 extern void        esl_regexp_Destroy(ESL_REGEXP *machine);
 
-extern int  esl_regexp_Match(ESL_REGEXP *machine, const char *pattern, const char *s);
-extern int  esl_regexp_Compile(ESL_REGEXP *machine, const char *pattern);
+extern int  esl_regexp_Compile        (ESL_REGEXP *machine, const char *pattern);
+extern int  esl_regexp_Match          (ESL_REGEXP *machine, const char *pattern, const char *s);
 extern int  esl_regexp_MultipleMatches(ESL_REGEXP *machine, char **sptr);
 
-extern char *esl_regexp_SubmatchDup(ESL_REGEXP *machine, int elem);
-extern int   esl_regexp_SubmatchCopy(ESL_REGEXP *machine, int elem, char *buffer, int nc);
-extern int   esl_regexp_SubmatchCoords(ESL_REGEXP *machine, char *origin, int elem, 
-				       int *ret_start, int *ret_end);
-extern int   esl_regexp_ParseCoordString(const char *cstring, uint32_t *ret_start, uint32_t *ret_end);
+extern int   esl_regexp_GetMatch      (ESL_REGEXP *machine, int which, char **ret_s, esl_pos_t *ret_n);
+extern char *esl_regexp_SubmatchDup   (ESL_REGEXP *machine, int elem);
+extern int   esl_regexp_SubmatchCopy  (ESL_REGEXP *machine, int elem, char *buffer, int nc);
+extern int   esl_regexp_SubmatchCoords(ESL_REGEXP *machine, char *origin, int elem, int *ret_start, int *ret_end);
+
+extern int   esl_regexp_ParseCoordString(const char *cstring, int64_t *ret_start, int64_t *ret_end);
 
 #endif /*eslREGEXP_INCLUDED*/
 
