@@ -4,7 +4,7 @@
  */
 #ifndef ESL_ROOTFINDER_INCLUDED
 #define ESL_ROOTFINDER_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
 typedef struct {
   int   (*func)(double, void*, double*);
