@@ -2,6 +2,7 @@
  */
 #ifndef eslSCOREMATRIX_INCLUDED
 #define eslSCOREMATRIX_INCLUDED
+#include <esl_config.h>
 
 #include "esl_alphabet.h"
 #include "esl_fileparser.h"
@@ -69,15 +70,7 @@ extern int esl_scorematrix_Probify(const ESL_SCOREMATRIX *S, ESL_DMATRIX **opt_P
 				   double **opt_fi, double **opt_fj, double *opt_lambda);
 
 #endif /*eslSCOREMATRIX_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/ 
+
 
 
 
