@@ -4,7 +4,7 @@
  */
 #ifndef eslSSI_INCLUDED
 #define eslSSI_INCLUDED
-#ifdef eslAUGMENT_SSI
+#include <esl_config.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -16,9 +16,9 @@
 #include <inttypes.h>
 #endif
 
-#define eslSSI_MAXFILES 32767	     /* 2^15-1 */
-#define eslSSI_MAXKEYS  2147483647L  /* 2^31-1 */
-#define eslSSI_MAXRAM   256	     /* >256MB indices trigger external sort */
+#define eslSSI_MAXFILES 32767 	      // 2^15-1 
+#define eslSSI_MAXKEYS  (1ULL<<63)-1  // 2^63-1 
+#define eslSSI_MAXRAM   2048	      // >2048MB indices trigger external sort 
 
 #ifndef HAVE_FSEEKO
 #define fseeko fseek
@@ -152,18 +152,5 @@ extern int      esl_fwrite_i32(FILE *fp, int32_t  n);
 extern int      esl_fwrite_i64(FILE *fp, int64_t  n);
 extern int	esl_fread_offset(FILE *fp, int mode, off_t *ret_offset);
 extern int      esl_fwrite_offset(FILE *fp, off_t offset);
-#endif /* eslAUGMENT_SSI*/
-#ifndef eslAUGMENT_SSI
-typedef void ESL_SSI;
-typedef void ESL_NEWSSI;
-#endif
+
 #endif /* eslSSI_INCLUDED */
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
