@@ -3,11 +3,10 @@
  * SRE, Wed Feb 22 19:30:36 2006 [St. Louis] [moved to Easel]
  * SRE, Thu Aug  3 08:00:35 2000 [St. Louis] [moved to SQUID]
  * SRE, Fri Nov 26 14:54:21 1999 [St. Louis] [HMMER]
- * SVN $Id$
- * SVN $URL$
  */
 #ifndef eslSTOPWATCH_INCLUDED
 #define eslSTOPWATCH_INCLUDED
+#include <esl_config.h>
 
 #include <time.h>
 #ifdef HAVE_TIMES
@@ -54,14 +53,5 @@ extern int esl_stopwatch_Include(ESL_STOPWATCH *master, ESL_STOPWATCH *w);
 
 
 #endif /*eslSTOPWATCH_INCLUDED*/ 
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
 
 
