@@ -7,7 +7,7 @@
  *   
  * 
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include "easel.h"
 #include "esl_composition.h"
@@ -217,15 +217,3 @@ utest_Score(char *s1, char *s2, ESL_SCOREMATRIX *S, int gop, int gex, int expect
 
 
 
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- * 
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
