@@ -1,14 +1,13 @@
 /* Phylogenetic trees.
  * 
  * SRE, Tue May  2 13:54:30 2006 [St. Louis]
- * SVN $Id$
- * SVN $URL$
  */
 #ifndef eslTREE_INCLUDED
 #define eslTREE_INCLUDED
+#include <esl_config.h>
 
-#include <esl_dmatrix.h>
-#include <esl_random.h>
+#include "esl_dmatrix.h"
+#include "esl_random.h"
 
 /* Object: ESL_TREE
  *
@@ -117,13 +116,4 @@ extern int esl_tree_ToDistanceMatrix(ESL_TREE *T, ESL_DMATRIX **ret_D);
 
 
 #endif /*eslTREE_INCLUDED*/
-/*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version 0.43; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute
- * Other copyrights also apply. See the LICENSE file for a full list.
- * 
- * Easel is open source software, distributed under the BSD license. See
- * the LICENSE file for more details.
- *****************************************************************/
 
