@@ -1,6 +1,6 @@
 /* Sequence and profile caches, used by the hmmpgmd daemon.
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
