@@ -2,7 +2,7 @@
  *  gcc -o generic_fwdback_rescaled_example -mssse3 -I. -I../easel -L../easel -L. generic_fwdback_rescaled.c  -lhmmer -leasel
  */
 
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <string.h>
 
@@ -67,7 +67,7 @@ main(int argc, char **argv)
 
 
   /* Open the HMM file */
-  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Open(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
  
   while ( (status = p7_hmmfile_Read(hfp, &abc, &hmm)) != eslEOF)
     {
