@@ -4,7 +4,7 @@
  *    1. The <esl_msa_hmmpgmd2msa> function
  *    2. Test driver
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -72,27 +72,21 @@
  *
  */
 int
-hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int *excl, int excl_size, int excl_all, ESL_MSA **ret_msa) {
-  int i, j;
-  int c;
-  int status;
-  uint32_t n = 0;
-  /* trace of the query sequence with N residues onto model with N match states */
-  P7_TRACE          *qtr         = NULL;
+hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int *excl, int excl_size, int excl_all, ESL_MSA **ret_msa)
+{
+  HMMD_SEARCH_STATS *stats       = NULL;         // pointer to a single stats object, at the beginning of data 
+  P7_TRACE          *qtr         = NULL;         // trace of the query sequence with N residues onto model with N match states 
+  P7_TOPHITS         *th         = NULL;
+  ESL_MSA           *msa         = NULL;
+  char              *p           = (char*)data;  // pointer used to walk along data, must be char* to allow pointer arithmetic 
   int                extra_sqcnt = 0;
+  uint32_t n = 0;
+  int      i;
+  int      c;
+  int      status;
 
-  /* vars used to read from the binary data */
-  HMMD_SEARCH_STATS *stats   = NULL;              /* pointer to a single stats object, at the beginning of data */
-
-  /* vars used in msa construction */
-  P7_TOPHITS         th;
-  ESL_MSA           *msa   = NULL;
-
-  char              *p     = (char*)data;        /*pointer used to walk along data, must be char* to allow pointer arithmetic */
-
-  th.N = 0;
-  th.unsrt = NULL;
-  th.hit   = NULL;
+  
+  th = p7_tophits_Create();
   ESL_ALLOC(stats, sizeof(HMMD_SEARCH_STATS));
   stats->hit_offsets = NULL; // we don't use hit_offsets for this test
   /* optionally build a faux trace for the query sequence: relative to core model (B->M_1..M_L->E) */
@@ -129,27 +123,28 @@ hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int
   }
 
   /* ok, it looks legitimate */
-  /* create a tophits object, to be passed to p7_tophits_Alignment() */
-  ESL_ALLOC( th.unsrt, sizeof(P7_HIT) * stats->nhits);
+  while(stats->nhits > th->Nalloc){ // make sure we have enough space in the tophits structure
+    p7_tophits_Grow(th);
+  }
+
   // deserialize all the hits
   for (i = 0; i < stats->nhits; ++i) {
     // set all internal pointers of the hit to NULL before deserializing into it
-    th.unsrt[i].name = NULL;
-    th.unsrt[i].acc = NULL;
-    th.unsrt[i].desc = NULL;
-    th.unsrt[i].dcl = NULL;
+    th->unsrt[i].name = NULL;
+    th->unsrt[i].acc = NULL;
+    th->unsrt[i].desc = NULL;
+    th->unsrt[i].dcl = NULL;
 
-    if(p7_hit_Deserialize((uint8_t *) p, &n, &(th.unsrt[i])) != eslOK){
+    if(p7_hit_Deserialize((uint8_t *) p, &n, &(th->unsrt[i])) != eslOK){
       printf("Unable to deserialize hit %d\n", i);
       exit(0);
     }  
   }
 
-  ESL_ALLOC( th.hit, sizeof(P7_HIT*) * stats->nhits);
   for (i=0; i<stats->nhits; i++) {
-    th.hit[i] = &(th.unsrt[i]);
-    if (   th.hit[i]->ndom > 10000
-        || th.hit[i]->flags >  p7_IS_INCLUDED + p7_IS_REPORTED + p7_IS_NEW + p7_IS_DROPPED + p7_IS_DUPLICATE
+    th->hit[i] = &(th->unsrt[i]);
+    if (   th->hit[i]->ndom > 10000
+        || th->hit[i]->flags >  p7_IS_INCLUDED + p7_IS_REPORTED + p7_IS_NEW + p7_IS_DROPPED + p7_IS_DUPLICATE
     ) {
       status = eslFAIL;
       goto ERROR;
@@ -157,31 +152,31 @@ hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int
   }
 
 //  th.unsrt     = NULL;
-  th.N         = stats->nhits;
-  th.nreported = 0;
-  th.nincluded = 0;
-  th.is_sorted_by_sortkey = 0;
-  th.is_sorted_by_seqidx  = 0;
+  th->N         = stats->nhits;
+  th->nreported = 0;
+  th->nincluded = 0;
+  th->is_sorted_by_sortkey = 0;
+  th->is_sorted_by_seqidx  = 0;
 
   /* jackhmmer (hmmer web) - allow all hits to be unchecked */
   if(excl_all){
-    for (i = 0; i < th.N; i++) {
+    for (i = 0; i < th->N; i++) {
       /* Go through the hits and set all to be excluded */
-      if(th.hit[i]->flags & p7_IS_INCLUDED){
-        th.hit[i]->flags = p7_IS_DROPPED;
-        th.hit[i]->nincluded = 0;
+      if(th->hit[i]->flags & p7_IS_INCLUDED){
+        th->hit[i]->flags = p7_IS_DROPPED;
+        th->hit[i]->nincluded = 0;
       }
     }
   }
 
-  for (i = 0; i < th.N; i++) {
+  for (i = 0; i < th->N; i++) {
     /* Go through the hits and set to be excluded or included as necessary */
-    if(th.hit[i]->flags & p7_IS_INCLUDED){
+    if(th->hit[i]->flags & p7_IS_INCLUDED){
       if(excl_size > 0){
         for( c = 0; c < excl_size; c++){
-          if(excl[c] == (long)(th.hit[i]->name) ){
-            th.hit[i]->flags = p7_IS_DROPPED;
-            th.hit[i]->nincluded = 0;
+          if(excl[c] == (long)(th->hit[i]->name) ){
+            th->hit[i]->flags = p7_IS_DROPPED;
+            th->hit[i]->nincluded = 0;
             break;
           }
         }
@@ -189,8 +184,8 @@ hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int
     }else{
       if(incl_size > 0){
     	for( c = 0; c < incl_size; c++){
-          if(incl[c] == (long)th.hit[i]->name ){
-            th.hit[i]->flags = p7_IS_INCLUDED;
+          if(incl[c] == (long)th->hit[i]->name ){
+            th->hit[i]->flags = p7_IS_INCLUDED;
           }
         }
       }
@@ -199,38 +194,22 @@ hmmpgmd2msa(void *data, P7_HMM *hmm, ESL_SQ *qsq, int *incl, int incl_size, int
 
 
   /* use the tophits and trace info above to produce an alignment */
-  if ( (status = p7_tophits_Alignment(&th, hmm->abc, &qsq, &qtr, extra_sqcnt, p7_ALL_CONSENSUS_COLS, &msa)) != eslOK) goto ERROR;
+  if ( (status = p7_tophits_Alignment(th, hmm->abc, &qsq, &qtr, extra_sqcnt, p7_ALL_CONSENSUS_COLS, &msa)) != eslOK) goto ERROR;
   esl_msa_SetName     (msa, hmm->name, -1);
   esl_msa_SetAccession(msa, hmm->acc,  -1);
   esl_msa_SetDesc     (msa, hmm->desc, -1);
   esl_msa_FormatAuthor(msa, "hmmpgmd (HMMER %s)", HMMER_VERSION);
 
-  /* free memory */
   if (qtr != NULL) free(qtr);
-  for (i = 0; i < th.N; i++) {
-    for (j=0; j < th.hit[i]->ndom; j++)
-      p7_alidisplay_Destroy(th.hit[i]->dcl[j].ad);
+  p7_tophits_Destroy(th);
 
-    if (th.hit[i]->dcl != NULL) free (th.hit[i]->dcl);
-  }
-  if (th.unsrt != NULL) free (th.unsrt);
-  if (th.hit != NULL) free (th.hit);
   free(stats);
   *ret_msa = msa;
   return eslOK;
 
 ERROR:
-  /* free memory */
   if (qtr != NULL) free(qtr);
-
-  for (i = 0; i < th.N; i++) {
-    for (j=0; j < th.hit[i]->ndom; j++)
-      p7_alidisplay_Destroy(th.hit[i]->dcl[j].ad);
-
-    if (th.hit[i]->dcl != NULL) free (th.hit[i]->dcl);
-  }
-  if (th.unsrt != NULL) free (th.unsrt);
-  if (th.hit != NULL) free (th.hit);
+  p7_tophits_Destroy(th);
   if(stats != NULL) free(stats);
   return status;
 }
@@ -537,13 +516,14 @@ void hmmpgmd2msa_utest(int ntrials, char *hmmfile){
   HMMD_SEARCH_STATS stats;
   uint32_t n = 0;
   uint32_t nalloc = 0;
+  int i, j, k;
 
   buf_data = NULL;
   buf = &(buf_data);
 
   // Grab the HMM from the input file
-  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_Open(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)           != eslOK) p7_Fail("Failed to read HMM");
   p7_hmmfile_Close(hfp);
 
   P7_PROFILE *profile = p7_profile_Create(hmm->M, abc);
@@ -560,10 +540,10 @@ void hmmpgmd2msa_utest(int ntrials, char *hmmfile){
   P7_PIPELINE *pli=p7_pipeline_Create(NULL, hmm->M, 400, FALSE, p7_SEARCH_SEQS);
   p7_pli_NewModel(pli, oprofile, bg);
 
-  for(int j = 0; j < ntrials; j++){
+  for(j = 0; j < ntrials; j++){
     
     // sample sequences from the HMM
-    for(int i = 0; i < NUM_TEST_SEQUENCES; i++){
+    for(i = 0; i < NUM_TEST_SEQUENCES; i++){
       sequences[i] = esl_sq_CreateDigital(abc);
       p7_ProfileEmit(rng, hmm, profile, bg, sequences[i], NULL);
     }
@@ -571,7 +551,7 @@ void hmmpgmd2msa_utest(int ntrials, char *hmmfile){
     hitlist = p7_tophits_Create();
 
     // Search all of the sampled sequences against the HMM to generate a set of hits
-    for(int i = 0; i < NUM_TEST_SEQUENCES; i++){
+    for(i = 0; i < NUM_TEST_SEQUENCES; i++){
       p7_pli_NewSeq(pli, sequences[i]);
       p7_bg_SetLength(bg, sequences[i]->n);
       p7_oprofile_ReconfigLength(oprofile, sequences[i]->n);
@@ -617,7 +597,7 @@ void hmmpgmd2msa_utest(int ntrials, char *hmmfile){
       p7_Fail(msg);
     }
 
-    for(int k = 0; k < hitlist->N; k++){
+    for(k = 0; k < hitlist->N; k++){
       if(p7_hit_Serialize(hitlist->hit[k], buf, &n, &nalloc) !=eslOK){
         p7_Fail(msg);
       }
@@ -634,7 +614,7 @@ void hmmpgmd2msa_utest(int ntrials, char *hmmfile){
 
     // clean up after ourselves 
     p7_tophits_Destroy(hitlist);
-    for(int k = 0; k < NUM_TEST_SEQUENCES; k++){
+    for(k = 0; k < NUM_TEST_SEQUENCES; k++){
       esl_sq_Destroy(sequences[k]);
       sequences[k] = NULL;
     }
