@@ -3,14 +3,14 @@
  * Main testbed for exploring the statistical behavior of HMMER3
  * scores on random sequences.
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
 #include "mpi.h"
 #endif 
 
@@ -41,7 +41,7 @@ static ESL_OPTIONS options[] = {
   { "-v",        eslARG_NONE,   FALSE, NULL, NULL,      NULL,  NULL, NULL, "verbose: print scores",                             1 },
   { "-L",        eslARG_INT,    "100", NULL, "n>0",     NULL,  NULL, NULL, "length of random target seqs",                      1 },
   { "-N",        eslARG_INT,   "1000", NULL, "n>0",     NULL,  NULL, NULL, "number of random target seqs",                      1 },
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
   { "--mpi",     eslARG_NONE,   FALSE, NULL, NULL,      NULL,  NULL, NULL, "run as an MPI parallel program",                    1 },
 #endif
   { "-o",        eslARG_OUTFILE, NULL, NULL, NULL,      NULL,  NULL, NULL, "direct output to file <f>, not stdout",             2 },
@@ -123,18 +123,15 @@ struct cfg_s {
 static int  init_master_cfg(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf);
 
 static void serial_master  (ESL_GETOPTS *go, struct cfg_s *cfg);
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
 static void mpi_master     (ESL_GETOPTS *go, struct cfg_s *cfg);
 static void mpi_worker     (ESL_GETOPTS *go, struct cfg_s *cfg);
+static int  minimum_mpi_working_buffer(ESL_GETOPTS *go, int N, int *ret_wn);
 #endif 
 static int process_workunit   (ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm, double *scores, int *alilens, double *ret_mu, double *ret_lambda);
 static int output_result      (ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm, double *scores, int *alilens, double mu, double lambda);
 static int output_filter_power(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm, double *scores, double mu, double lambda);
 
-#ifdef HAVE_MPI
-static int minimum_mpi_working_buffer(ESL_GETOPTS *go, int N, int *ret_wn);
-#endif 
-
 static int elide_length_model(P7_PROFILE *gm, P7_BG *bg);
 
 int
@@ -194,7 +191,7 @@ main(int argc, char **argv)
    */
   cfg.hmmfile  = esl_opt_GetArg(go, 1);
   cfg.r        = esl_randomness_Create(esl_opt_GetInteger(go, "--seed"));
-  //cfg.abc      = esl_alphabet_Create(eslAMINO);
+  cfg.abc      = NULL;
 
   cfg.my_rank  = 0;		/* MPI init will change this soon, if --mpi was set */
   cfg.nproc    = 0;		/* MPI init will change this soon, if --mpi was set */
@@ -225,7 +222,7 @@ main(int argc, char **argv)
   /* Main body:
    * Handed off to serial version or MPI masters and workers as appropriate.
    */
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
   if (esl_opt_GetBoolean(go, "--mpi")) 
     {
       /* Initialize MPI, figure out who we are, and whether we're running
@@ -245,7 +242,7 @@ main(int argc, char **argv)
       MPI_Finalize();		/* both workers and masters reach this line */
     }
   else
-#endif /*HAVE_MPI*/
+#endif /*HMMER_MPI*/
     {		
       /* No MPI? Then we're just the serial master. */
       serial_master(go, &cfg);
@@ -300,7 +297,7 @@ init_master_cfg(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf)
   char *filename;
   int   status;
 
-  status = p7_hmmfile_OpenE(cfg->hmmfile, NULL, &(cfg->hfp), NULL);
+  status = p7_hmmfile_Open(cfg->hmmfile, NULL, &(cfg->hfp), NULL);
   if      (status == eslENOTFOUND) ESL_FAIL(eslFAIL, errbuf, "Failed to open HMM file %s for reading.\n",                   cfg->hmmfile);
   else if (status == eslEFORMAT)   ESL_FAIL(eslFAIL, errbuf, "File %s does not appear to be in a recognized HMM format.\n", cfg->hmmfile);
   else if (status != eslOK)        ESL_FAIL(eslFAIL, errbuf, "Unexpected error %d in opening HMM file %s.\n",       status, cfg->hmmfile);  
@@ -393,7 +390,7 @@ serial_master(ESL_GETOPTS *go, struct cfg_s *cfg)
 }
 
 
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
 /* mpi_master()
  * The MPI version of hmmsim.
  * Follows standard pattern for a master/worker load-balanced MPI program (J1/78-79).
@@ -452,17 +449,17 @@ mpi_master(ESL_GETOPTS *go, struct cfg_s *cfg)
 	  if ((status = p7_hmmfile_Read(cfg->hfp, &(cfg->abc), &hmm)) != eslOK) 
 	    {
 	      have_work = FALSE;
-	      if      (status == eslEOD)       { xstatus = status; sprintf(errbuf, "read failed, HMM file %s may be truncated?", cfg->hmmfile); }
-	      else if (status == eslEFORMAT)   { xstatus = status; sprintf(errbuf, "bad file format in HMM file %s",             cfg->hmmfile); }
-	      else if (status == eslEINCOMPAT) { xstatus = status; sprintf(errbuf, "HMM file %s contains different alphabets",   cfg->hmmfile); }
-	      else if (status != eslEOF)       { xstatus = status; sprintf(errbuf, "Unexpected error in reading HMMs from %s",   cfg->hmmfile); }
+	      if      (status == eslEOD)       { xstatus = status; snprintf(errbuf, eslERRBUFSIZE, "read failed, HMM file %s may be truncated?", cfg->hmmfile); }
+	      else if (status == eslEFORMAT)   { xstatus = status; snprintf(errbuf, eslERRBUFSIZE, "bad file format in HMM file %s",             cfg->hmmfile); }
+	      else if (status == eslEINCOMPAT) { xstatus = status; snprintf(errbuf, eslERRBUFSIZE, "HMM file %s contains different alphabets",   cfg->hmmfile); }
+	      else if (status != eslEOF)       { xstatus = status; snprintf(errbuf, eslERRBUFSIZE, "Unexpected error in reading HMMs from %s",   cfg->hmmfile); }
 
 	      if (cfg->bg == NULL) { // first time only
-          if (esl_opt_GetBoolean(go, "--bgflat")) cfg->bg = p7_bg_CreateUniform(cfg->abc);
-          else                                    cfg->bg = p7_bg_Create(cfg->abc);
+                if (esl_opt_GetBoolean(go, "--bgflat")) cfg->bg = p7_bg_CreateUniform(cfg->abc);
+                else                                    cfg->bg = p7_bg_Create(cfg->abc);
 	      }
 	      //this next step is redundant, but it avoids a race condition above.
-        p7_bg_SetLength(cfg->bg, esl_opt_GetInteger(go, "-L"));  /* set the null model background length in both master and workers. */
+              p7_bg_SetLength(cfg->bg, esl_opt_GetInteger(go, "-L"));  /* set the null model background length in both master and workers. */
 	    }
 	}
 
@@ -539,7 +536,6 @@ mpi_master(ESL_GETOPTS *go, struct cfg_s *cfg)
 static void
 mpi_worker(ESL_GETOPTS *go, struct cfg_s *cfg)
 {
-  int             xstatus = eslOK;
   int             status;
   P7_HMM         *hmm     = NULL;
   char           *wbuf    = NULL;
@@ -551,7 +547,7 @@ mpi_worker(ESL_GETOPTS *go, struct cfg_s *cfg)
   double          mu, lambda;
  
   /* Worker initializes */
-  if ((status = minimum_mpi_working_buffer(go, cfg->N, &wn)) != eslOK) xstatus = status;
+  if ((status = minimum_mpi_working_buffer(go, cfg->N, &wn)) != eslOK) goto ERROR;
   ESL_ALLOC(wbuf, wn * sizeof(char));
   ESL_ALLOC(xv,   cfg->N * sizeof(double) + 2);	
   if (esl_opt_GetBoolean(go, "-a"))
@@ -560,6 +556,10 @@ mpi_worker(ESL_GETOPTS *go, struct cfg_s *cfg)
   /* Main worker loop */
   while (p7_hmm_MPIRecv(0, 0, MPI_COMM_WORLD, &wbuf, &wn, &(cfg->abc), &hmm) == eslOK) 
     {
+    if (cfg->bg == NULL) { // first time only
+          if (esl_opt_GetBoolean(go, "--bgflat")) cfg->bg = p7_bg_CreateUniform(cfg->abc);
+          else                                    cfg->bg = p7_bg_Create(cfg->abc);
+        }
       if ((status = process_workunit(go, cfg, errbuf, hmm, xv, av, &mu, &lambda)) != eslOK) goto CLEANERROR;
 
       pos = 0;
@@ -593,7 +593,7 @@ mpi_worker(ESL_GETOPTS *go, struct cfg_s *cfg)
  ERROR:
   p7_Fail("Allocation error in mpi_worker");
 }
-#endif /*HAVE_MPI*/
+#endif /*HMMER_MPI*/
 
 
 /* process_workunit()
@@ -630,6 +630,9 @@ process_workunit(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm,
   double Eft          = esl_opt_GetReal   (go, "--Eft");
   float  nu           = esl_opt_GetReal   (go, "--nu");
 
+
+  // reseed the RNG to its initial value, to allow reproduction of results
+  esl_randomness_Init(cfg->r, esl_opt_GetInteger(go, "--seed"));
   /* Optionally set a custom background, determined by model composition;
    * an experimental hack. 
    */
@@ -638,7 +641,7 @@ process_workunit(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm,
       float *p = NULL;
       float  KL;
 
-      p7_hmm_CompositionKLDist(hmm, cfg->bg, &KL, &p);
+      p7_hmm_CompositionKLD(hmm, cfg->bg, &KL, &p);
       esl_vec_FCopy(p, cfg->abc->K, cfg->bg->f);
     }
 
@@ -723,7 +726,7 @@ process_workunit(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hmm,
   p7_profile_Destroy(gm);
   p7_gmx_Destroy(gx);
   p7_trace_Destroy(tr);
-  if (status == eslEMEM) sprintf(errbuf, "allocation failure");
+  if (status == eslEMEM) snprintf(errbuf, eslERRBUFSIZE, "allocation failure");
   return status;
 }
 
@@ -907,7 +910,7 @@ output_filter_power(ESL_GETOPTS *go, struct cfg_s *cfg, char *errbuf, P7_HMM *hm
 
 
 
-#ifdef HAVE_MPI
+#ifdef HMMER_MPI
 /* the pack send/recv buffer must be big enough to hold either an error message or a result vector.
  * it may even grow larger than that, to hold largest HMM we send.
  */
@@ -919,18 +922,18 @@ minimum_mpi_working_buffer(ESL_GETOPTS *go, int N, int *ret_wn)
   int nresult = 0;
 
   /* error packet */
-  if (MPI_Pack_size(eslERRBUFSIZE, MPI_CHAR,   MPI_COMM_WORLD, &nerr)!= 0)return eslESYS;   
+  if (MPI_Pack_size(eslERRBUFSIZE, MPI_CHAR,   MPI_COMM_WORLD, &nerr)!= 0) return eslESYS; 
   
   /* results packet */
-  if (MPI_Pack_size(N,             MPI_DOUBLE, MPI_COMM_WORLD, &n)  != 0) return eslESYS;   nresult += n;   /* scores */
+  if (MPI_Pack_size(N, MPI_DOUBLE, MPI_COMM_WORLD, &n)  != 0) return eslESYS; else nresult += n;     /* scores */
   if (esl_opt_GetBoolean(go, "-a")) {
-    if (MPI_Pack_size(N,           MPI_INT,    MPI_COMM_WORLD, &n)  != 0) return eslESYS;   nresult += n;   /* alignment lengths */
+    if (MPI_Pack_size(N, MPI_INT,  MPI_COMM_WORLD, &n)  != 0) return eslESYS; else nresult += n;     /* alignment lengths */
   }
-  if (MPI_Pack_size(1,             MPI_DOUBLE, MPI_COMM_WORLD, &n)  != 0) return eslESYS;   nresult += n*2; /* mu, lambda */
+  if (MPI_Pack_size(1, MPI_DOUBLE, MPI_COMM_WORLD, &n)  != 0) return eslESYS; else nresult += n*2;   /* mu, lambda */
 
   /* add the shared status code to the max of the two possible kinds of packets */
   *ret_wn =  ESL_MAX(nresult, nerr);
-  if (MPI_Pack_size(1,             MPI_INT,    MPI_COMM_WORLD, &n)  != 0) return eslESYS;   *ret_wn += n;   /* status code */
+  if (MPI_Pack_size(1, MPI_INT, MPI_COMM_WORLD, &n)  != 0) return eslESYS; else *ret_wn += n;   
   return eslOK;
 }
 #endif
@@ -961,15 +964,3 @@ elide_length_model(P7_PROFILE *gm, P7_BG *bg)
 }
 
 
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- * 
- * SVN $URL$
- * SVN $Id$
- *****************************************************************/
