@@ -2,12 +2,11 @@
  * routines: structures, declarations, and macros.
  * 
  * SRE, Sun Nov 25 11:23:02 2007
- * SVN $Id$
  */
 #ifndef P7_IMPL_SSE_INCLUDED
 #define P7_IMPL_SSE_INCLUDED
 
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "esl_alphabet.h"
 #include "esl_random.h"
@@ -194,8 +193,8 @@ typedef struct p7_omx_s {
   int       validR;    /* current # of rows actually pointing at DP memory            */
   int       allocQ4;    /* current set row width in <dpf> quads:   allocQ4*4 >= M      */
   int       allocQ8;    /* current set row width in <dpw> octets:  allocQ8*8 >= M      */
-  int       allocQ16;    /* current set row width in <dpb> 16-mers: allocQ16*16 >= M    */
-  size_t    ncells;    /* current allocation size of <dp_mem>, in accessible cells    */
+  int       allocQ16;   /* current set row width in <dpb> 16-mers: allocQ16*16 >= M    */
+  int64_t   ncells;     /* current allocation size of <dp_mem>, in accessible cells    */
 
   /* The X states (for full,parser; or NULL, for scorer)                                       */
   float    *xmx;          /* logically [0.1..L][ENJBCS]; indexed [i*p7X_NXCELLS+s]       */
@@ -377,16 +376,6 @@ impl_Init(void)
 #endif /* P7_IMPL_SSE_INCLUDED */
 
 
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
-
 /* 
  * Currently (and this remains in flux as of 14 Dec 07) an optimized
  * implementation is required to provide an MSVFilter(),
