@@ -12,12 +12,10 @@
  *   3. Unit tests
  *   4. Test driver
  *   5. Example
- *   6. Copyright and license information
  * 
  * SRE, Sun Nov 25 11:26:48 2007 [Casa de Gatos]
- * SVN $Id$
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <math.h>
@@ -121,7 +119,7 @@ p7_MSVFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float
   xJv = _mm_subs_epu8(biasv, biasv);
   xBv = _mm_subs_epu8(basev, tjbmv);
 
-#if p7_DEBUGGING
+#if eslDEBUGLEVEL > 0
   if (ox->debugging)
   {
       uint8_t xB;
@@ -187,7 +185,7 @@ p7_MSVFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float
       xBv = _mm_max_epu8(basev, xJv);
       xBv = _mm_subs_epu8(xBv, tjbmv);
 	  
-#if p7_DEBUGGING
+#if eslDEBUGLEVEL > 0
       if (ox->debugging)
       {
         uint8_t xB, xE;
@@ -337,37 +335,38 @@ p7_SSVFilter_longtarget(const ESL_DSQ *dsq, int L, P7_OPROFILE *om, P7_OMX *ox,
 
   xBv = _mm_subs_epu8(basev, tjbmv);
 
-  for (i = 1; i <= L; i++) {
-    rsc = om->rbv[dsq[i]];
-    xEv = _mm_setzero_si128();
+  for (i = 1; i <= L; i++) 
+    {
+      rsc = om->rbv[dsq[i]];
+      xEv = _mm_setzero_si128();
 
-	  /* Right shifts by 1 byte. 4,8,12,x becomes x,4,8,12.
-	   * Because ia32 is littlendian, this means a left bit shift.
-	   * Zeros shift on automatically, which is our -infinity.
-	   */
-	  mpv = _mm_slli_si128(dp[Q-1], 1);
-	  for (q = 0; q < Q; q++) {
-		  /* Calculate new MMXo(i,q); don't store it yet, hold it in sv. */
-		  sv   = _mm_max_epu8(mpv, xBv);
-		  sv   = _mm_adds_epu8(sv, biasv);
-		  sv   = _mm_subs_epu8(sv, *rsc);   rsc++;
-		  xEv  = _mm_max_epu8(xEv, sv);
+      /* Right shifts by 1 byte. 4,8,12,x becomes x,4,8,12.
+       * Because ia32 is littlendian, this means a left bit shift.
+       * Zeros shift on automatically, which is our -infinity.
+       */
+      mpv = _mm_slli_si128(dp[Q-1], 1);
+      for (q = 0; q < Q; q++) {
+        /* Calculate new MMXo(i,q); don't store it yet, hold it in sv. */
+        sv   = _mm_max_epu8(mpv, xBv);
+        sv   = _mm_adds_epu8(sv, biasv);
+        sv   = _mm_subs_epu8(sv, *rsc);   rsc++;
+        xEv  = _mm_max_epu8(xEv, sv);
+        
+        mpv   = dp[q];   	  /* Load {MDI}(i-1,q) into mpv */
+        dp[q] = sv;       	  /* Do delayed store of M(i,q) now that memory is usable */
+      }
 
-		  mpv   = dp[q];   	  /* Load {MDI}(i-1,q) into mpv */
-		  dp[q] = sv;       	  /* Do delayed store of M(i,q) now that memory is usable */
-	  }
+      /* test if the pthresh significance threshold has been reached;
+       * note: don't use _mm_cmpgt_epi8, because it's a signed comparison, which won't work on uint8s */
+      tempv = _mm_adds_epu8(xEv, sc_threshv);
+      tempv = _mm_cmpeq_epi8(tempv, ceilingv);
+      cmp = _mm_movemask_epi8(tempv);
 
-	  /* test if the pthresh significance threshold has been reached;
-	   * note: don't use _mm_cmpgt_epi8, because it's a signed comparison, which won't work on uint8s */
-	  tempv = _mm_adds_epu8(xEv, sc_threshv);
-	  tempv = _mm_cmpeq_epi8(tempv, ceilingv);
-	  cmp = _mm_movemask_epi8(tempv);
-
-	  if (cmp != 0) {  //hit pthresh, so add position to list and reset values
-	    //figure out which model state hit threshold
-	    end = -1;
-	    rem_sc = -1;
-	    for (q = 0; q < Q; q++) {  /// Unpack and unstripe, so we can find the state that exceeded pthresh
+      if (cmp != 0) {  //hit pthresh, so add position to list and reset values
+        //figure out which model state hit threshold
+        end = -1;
+        rem_sc = -1;
+        for (q = 0; q < Q; q++) {  /// Unpack and unstripe, so we can find the state that exceeded pthresh
           u.v = dp[q];
           for (k = 0; k < 16; k++) { // unstripe
             //(q+Q*k+1) is the model position k at which the xE score is found
@@ -377,70 +376,66 @@ p7_SSVFilter_longtarget(const ESL_DSQ *dsq, int L, P7_OPROFILE *om, P7_OMX *ox,
             }
           }
           dp[q] = _mm_set1_epi8(0); // while we're here ... this will cause values to get reset to xB in next dp iteration
-	    }
+        }
 
-	    //recover the diagonal that hit threshold
-	    start = end;                    // model position
-	    target_end = target_start = i;  // target position
-	    sc = rem_sc;
-	    while (rem_sc > om->base_b - om->tjb_b - om->tbm_b) {
-	      rem_sc -= om->bias_b -  ssvdata->ssv_scores[start*om->abc->Kp + dsq[target_start]];
-	      --start;
-	      --target_start;
-	    }
-	    start++;
-	    target_start++;
+        //recover the diagonal that hit threshold
+        start = end;                    // model position
+        target_end = target_start = i;  // target position
+        sc = rem_sc;
+        while (rem_sc > om->base_b - om->tjb_b - om->tbm_b) {
+          rem_sc -= om->bias_b -  ssvdata->ssv_scores[start*om->abc->Kp + dsq[target_start]];
+          --start;
+          --target_start;
+        }
+        start++;
+        target_start++;
 
 
-	    //extend diagonal further with single diagonal extension
-	    k = end+1;
-	    n = target_end+1;
-	    max_end = target_end;
-	    max_sc = sc;
-	    pos_since_max = 0;
-	    while (k<om->M && n<=L) {
-	      sc += om->bias_b -  ssvdata->ssv_scores[k*om->abc->Kp + dsq[n]];
+        //extend diagonal further with single diagonal extension
+        k = end+1;
+        n = target_end+1;
+        max_end = target_end;
+        max_sc = sc;
+        pos_since_max = 0;
+        while (k<om->M && n<=L) {
+          sc += om->bias_b -  ssvdata->ssv_scores[k*om->abc->Kp + dsq[n]];
+          
+          if (sc >= max_sc) {
+            max_sc = sc;
+            max_end = n;
+            pos_since_max=0;
+          } else {
+            pos_since_max++;
+            if (pos_since_max == 5)
+              break;
+          }
+          k++;
+          n++;
+        }
 
-	      if (sc >= max_sc) {
-	        max_sc = sc;
-	        max_end = n;
-	        pos_since_max=0;
-	      } else {
-	        pos_since_max++;
-	        if (pos_since_max == 5)
-	          break;
-	      }
-	      k++;
-	      n++;
-	    }
+        end  +=  (max_end - target_end);
+        //k    +=  (max_end - target_end);
+        target_end = max_end;
 
-	    end  +=  (max_end - target_end);
-      //k    +=  (max_end - target_end);
-      target_end = max_end;
+        ret_sc = ((float) (max_sc - om->tjb_b) - (float) om->base_b);
+        ret_sc /= om->scale_b;
+        ret_sc -= 3.0; // that's ~ L \log \frac{L}{L+3}, for our NN,CC,JJ
 
-      ret_sc = ((float) (max_sc - om->tjb_b) - (float) om->base_b);
-      ret_sc /= om->scale_b;
-      ret_sc -= 3.0; // that's ~ L \log \frac{L}{L+3}, for our NN,CC,JJ
-
-      p7_hmmwindow_new(  windowlist,
-                         0,                  // sequence_id; used in the FM-based filter, but not here
-                         target_start,       // position in the target at which the diagonal starts
-                         0,                  // position in the target fm_index at which diagonal starts;  not used here, just in FM-based filter
-                         end,                // position in the model at which the diagonal ends
-                         end-start+1 ,       // length of diagonal
-                         ret_sc,             // score of diagonal
-                         p7_NOCOMPLEMENT,    // always p7_NOCOMPLEMENT here;  varies in FM-based filter
-                         L
-                       );
-
-      i = target_end; // skip forward
-	  }
-
-
-  } /* end loop over sequence residues 1..L */
+        p7_hmmwindow_new(  windowlist,
+                           0,                  // sequence_id; used in the FM-based filter, but not here
+                           target_start,       // position in the target at which the diagonal starts
+                           0,                  // position in the target fm_index at which diagonal starts;  not used here, just in FM-based filter
+                           end,                // position in the model at which the diagonal ends
+                           end-start+1 ,       // length of diagonal
+                           ret_sc,             // score of diagonal
+                           p7_NOCOMPLEMENT,    // always p7_NOCOMPLEMENT here;  varies in FM-based filter
+                           L
+                           );
 
+        i = target_end; // skip forward
+      }
+    } /* end loop over sequence residues 1..L */
   return eslOK;
-
 }
 /*------------------ end, p7_SSVFilter_longtarget() ------------------------*/
 
@@ -480,7 +475,7 @@ p7_SSVFilter_longtarget(const ESL_DSQ *dsq, int L, P7_OPROFILE *om, P7_OMX *ox,
    ./benchmark-msvfilter -N100 -c <hmmfile>   compare scores to generic impl
    ./benchmark-msvfilter -N100 -x <hmmfile>   compare scores to exact emulation
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_alphabet.h"
@@ -527,8 +522,8 @@ main(int argc, char **argv)
   float           sc1, sc2;
   double          base_time, bench_time, Mcs;
 
-  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_Open(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)           != eslOK) p7_Fail("Failed to read HMM");
 
   bg = p7_bg_Create(abc);
   p7_bg_SetLength(bg, L);
@@ -668,7 +663,7 @@ utest_msv_filter(ESL_RANDOMNESS *r, ESL_ALPHABET *abc, P7_BG *bg, int M, int L,
    gcc -g -Wall -msse2 -std=gnu99 -I.. -L.. -I../../easel -L../../easel -o msvfilter_utest -Dp7MSVFILTER_TESTDRIVE msvfilter.c -lhmmer -leasel -lm
    ./msvfilter_utest
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_alphabet.h"
@@ -743,7 +738,7 @@ main(int argc, char **argv)
    gcc -g -Wall -msse2 -std=gnu99 -I.. -L.. -I../../easel -L../../easel -o msvfilter_example -Dp7MSVFILTER_EXAMPLE msvfilter.c -lhmmer -leasel -lm
    ./msvfilter_example <hmmfile> <seqfile>
  */ 
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_alphabet.h"
@@ -788,8 +783,8 @@ main(int argc, char **argv)
   int             status;
 
   /* Read in one HMM */
-  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_Open(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)           != eslOK) p7_Fail("Failed to read HMM");
 
   /* Open sequence file for reading */
   sq     = esl_sq_CreateDigital(abc);
@@ -878,15 +873,5 @@ main(int argc, char **argv)
 /*---------------------- end, example ---------------------------*/
 
 
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
-
 
 
