@@ -10,9 +10,8 @@
  *   6. Unit tests.
  *   7. Test driver.
  *   8. Example.
- *   9. Copyright and license information.
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -1781,7 +1780,7 @@ p7_oprofile_Sample(ESL_RANDOMNESS *r, const ESL_ALPHABET *abc, const P7_BG *bg,
  *            or <eslFAIL> if not.
  * 
  *            Floating point comparisons are done to a tolerance
- *            of <tol> using <esl_FCompare()>.
+ *            of <tol> using <esl_FCompare_old()>.
  *            
  *            If a comparison fails, an informative error message is
  *            left in <errmsg> to indicate why.
@@ -1791,7 +1790,7 @@ p7_oprofile_Sample(ESL_RANDOMNESS *r, const ESL_ALPHABET *abc, const P7_BG *bg,
  *            
  * Args:      om1    - one optimized profile to compare
  *            om2    - the other
- *            tol    - floating point comparison tolerance; see <esl_FCompare()>
+ *            tol    - floating point comparison tolerance; see <esl_FCompare_old()>
  *            errmsg - ptr to array of at least <eslERRBUFSIZE> characters.
  *            
  * Returns:   <eslOK> on effective equality;  <eslFAIL> on difference.
@@ -1852,7 +1851,7 @@ p7_oprofile_Compare(const P7_OPROFILE *om1, const P7_OPROFILE *om2, float tol, c
     for (q = 0; q < Q4; q++)
       {
 	a4.v = om1->rfv[x][q]; b4.v = om2->rfv[x][q];
-	for (r = 0; r < 4; r++) if (esl_FCompare(a4.x[r], b4.x[r], tol) != eslOK)  ESL_FAIL(eslFAIL, errmsg, "comparison failed: rf[%d] elem %d", q, r);
+	for (r = 0; r < 4; r++) if (esl_FCompare_old(a4.x[r], b4.x[r], tol) != eslOK)  ESL_FAIL(eslFAIL, errmsg, "comparison failed: rf[%d] elem %d", q, r);
       }
   for (q = 0; q < 8*Q4; q++)
     {
@@ -2003,7 +2002,7 @@ p7_profile_SameAsVF(const P7_OPROFILE *om, P7_PROFILE *gm)
    icc -o benchmark-oprofile -O3 -static -I.. -L.. -I../../easel -L../../easel -Dp7OPROFILE_BENCHMARK p7_oprofile.c -lhmmer -leasel -lm 
    ./benchmark-sse <hmmfile>         runs benchmark
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_alphabet.h"
@@ -2040,8 +2039,8 @@ main(int argc, char **argv)
   int             N       = esl_opt_GetInteger(go, "-N");
   int             i;
 
-  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_Open(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)           != eslOK) p7_Fail("Failed to read HMM");
 
   bg = p7_bg_Create(abc);
   p7_bg_SetLength(bg, L);
@@ -2102,7 +2101,7 @@ main(int argc, char **argv)
 /* gcc -std=gnu99 -g -Wall -Dp7OPROFILE_EXAMPLE -I.. -I../../easel -L.. -L../../easel -o p7_oprofile_example p7_oprofile.c -lhmmer -leasel -lm
  * ./p7_oprofile_example <hmmfile>
  */
-#include "p7_config.h"
+#include <p7_config.h>
 #include <stdlib.h>
 #include "easel.h"
 #include "hmmer.h"
@@ -2121,7 +2120,7 @@ main(int argc, char **argv)
   int           status;
   char          errbuf[eslERRBUFSIZE];
 
-  status = p7_hmmfile_OpenE(hmmfile, NULL, &hfp, errbuf);
+  status = p7_hmmfile_Open(hmmfile, NULL, &hfp, errbuf);
   if      (status == eslENOTFOUND) p7_Fail("File existence/permissions problem in trying to open HMM file %s.\n%s\n", hmmfile, errbuf);
   else if (status == eslEFORMAT)   p7_Fail("File format problem in trying to open HMM file %s.\n%s\n",                hmmfile, errbuf);
   else if (status != eslOK)        p7_Fail("Unexpected error %d in opening HMM file %s.\n%s\n",               status, hmmfile, errbuf);  
@@ -2156,16 +2155,3 @@ main(int argc, char **argv)
 /*----------------------- end, example --------------------------*/
 
 
-
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *   
- * SVN $Id$
- * SVN $URL$
- *****************************************************************/
