@@ -3,17 +3,15 @@
  * Contents:
  *   1. Introduction
  *   2. p7_SSVFilter() implementation
- *   3. Copyright and license information
  * 
  * Bjarne Knudsen, CLC Bio
- * SVN $Id$
  */
 
 /*****************************************************************
  * 1. Introduction
  *****************************************************************/
  
-/* Here is a description of the major ides going into this
+/* Here is a description of the major ideas going into this
  * implementation of the SSV filter.
  *
  *
@@ -405,7 +403,7 @@
  *
  */
 
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <math.h>
 
@@ -856,7 +854,7 @@ get_xE(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om)
 #endif
   };
 
-  beginv =  _mm_set1_epi8(128);
+  beginv =  _mm_set1_epi8(-128);
   xEv    =  beginv;
 
   /* Use the highest number of bands but no more than MAX_BANDS */
@@ -926,13 +924,3 @@ p7_SSVFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, float *ret_sc)
 }
 
 
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
-
