@@ -6,14 +6,13 @@
  *     2. Unit tests.
  *     3. Test driver.
  *     4. Statistics collection driver.
- *     5. Copyright and license
  * 
  * Revised May 2005: xref STL9/77-81.       (Uniform fragment distribution)
  * Again, Sept 2005: xref STL10/24-26.      (Inherent target length dependency)
  * Again, Jan 2007:  xref STL11/125,136-137 (HMMER3)
  * Again, Jul 2007:  xref J1/103            (floating point ops)
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <math.h>
 #include <float.h>
@@ -319,7 +318,7 @@ utest_occupancy(P7_HMM *hmm)
   occ = malloc(sizeof(float) * (hmm->M+1));
   p7_hmm_CalculateOccupancy(hmm, occ, NULL);
   x = esl_vec_FSum(occ+1, hmm->M) / (float) hmm->M;
-  if (esl_FCompare(x, 0.6, 0.1) != eslOK)           esl_fatal(msg);
+  if (esl_FCompare_old(x, 0.6, 0.1) != eslOK)           esl_fatal(msg);
   free(occ);
   return;
 }
@@ -337,7 +336,7 @@ utest_occupancy(P7_HMM *hmm)
  */
 #include "easel.h"
 
-#include "p7_config.h"
+#include <p7_config.h>
 #include "hmmer.h"
 
 
@@ -375,7 +374,7 @@ main(int argc, char **argv)
 /* gcc -g -Wall -Dp7MODELCONFIG_STATS -I. -I../easel -L. -L../easel -o statprog modelconfig.c -lhmmer -leasel -lm
  * ./statprog
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -483,7 +482,7 @@ main(int argc, char **argv)
     {	/* Read the HMM (and get alphabet from it) */
       P7_HMMFILE      *hfp     = NULL;
 
-      status = p7_hmmfile_OpenE(hmmfile, NULL, &hfp, errbuf);
+      status = p7_hmmfile_Open(hmmfile, NULL, &hfp, errbuf);
       if      (status == eslENOTFOUND) p7_Fail("File existence/permissions problem in trying to open HMM file %s.\n%s\n", hmmfile, errbuf);
       else if (status == eslEFORMAT)   p7_Fail("File format problem in trying to open HMM file %s.\n%s\n",                hmmfile, errbuf);
       else if (status != eslOK)        p7_Fail("Unexpected error %d in opening HMM file %s.\n%s\n",               status, hmmfile, errbuf);  
@@ -1120,12 +1119,3 @@ profile_local_endpoints(ESL_RANDOMNESS *r, P7_HMM *core, P7_PROFILE *gm, ESL_SQ
 
 
 
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.1b3; July 2016
- * Copyright (C) 2016 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
