@@ -5,7 +5,7 @@
  *    2. Standardized model construction API.
  *    3. Internal functions.
  */   
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -294,9 +294,10 @@ p7_builder_SetScoreSystem(P7_BUILDER *bld, const char *mxfile, const char *env,
   if (bld->Q != NULL) esl_dmatrix_Destroy(bld->Q);
 
   /* Get the scoring matrix */
-  if ((bld->S  = esl_scorematrix_Create(bld->abc)) == NULL) { status = eslEMEM; goto ERROR; }
+ 
   if (mxfile == NULL) 
     {
+      if ((bld->S  = esl_scorematrix_Create(bld->abc)) == NULL) { status = eslEMEM; goto ERROR; }
       if (bld->abc->type == eslAMINO) {
         if ((status = esl_scorematrix_Set("BLOSUM62", bld->S)) != eslOK) goto ERROR;
       } else {
@@ -481,7 +482,7 @@ p7_Builder(P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg,
  *            
  * Args:      bld       - build configuration
  *            sq        - query sequence
- *            bg        - null model (needed to paramaterize insert emission probs)
+ *            bg        - null model (needed to parameterize insert emission probs)
  *            opt_hmm   - optRETURN: new HMM
  *            opt_gm    - optRETURN: profile corresponding to <hmm>
  *            opt_om    - optRETURN: optimized profile corresponding to <gm>
@@ -807,16 +808,20 @@ validate_msa(P7_BUILDER *bld, ESL_MSA *msa)
 static int
 relative_weights(P7_BUILDER *bld, ESL_MSA *msa)
 {
-  int status = eslOK;
+  ESL_MSAWEIGHT_CFG *cfg    = esl_msaweight_cfg_Create();
+  int                status = eslOK;
+
+  cfg->ignore_rf = (bld->arch_strategy == p7_ARCH_HAND ? FALSE : TRUE);  // PB weights use RF consensus columns only if --hand is set. [iss #180]
 
   if      (bld->wgt_strategy == p7_WGT_NONE)                    { esl_vec_DSet(msa->wgt, msa->nseq, 1.); }
   else if (bld->wgt_strategy == p7_WGT_GIVEN)                   ;
-  else if (bld->wgt_strategy == p7_WGT_PB)                      status = esl_msaweight_PB(msa); 
+  else if (bld->wgt_strategy == p7_WGT_PB)                      status = esl_msaweight_PB_adv(cfg, msa, /*ESL_MSAWEIGHT_DAT=*/ NULL); 
   else if (bld->wgt_strategy == p7_WGT_GSC)                     status = esl_msaweight_GSC(msa); 
   else if (bld->wgt_strategy == p7_WGT_BLOSUM)                  status = esl_msaweight_BLOSUM(msa, bld->wid); 
   else ESL_EXCEPTION(eslEINCONCEIVABLE, "no such weighting strategy");
 
   if (status != eslOK) ESL_FAIL(status, bld->errbuf, "failed to set relative weights in alignment");
+  esl_msaweight_cfg_Destroy(cfg);
   return eslOK;
 }
 
