@@ -6,7 +6,7 @@
  *   3. Unit tests
  *   4. Test driver
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "hmmer.h"
 
@@ -215,7 +215,7 @@ p7_gmx_Destroy(P7_GMX *gx)
  * Synopsis:  Compare two DP matrices for equality within given tolerance.
  *
  * Purpose:   Compare all the values in DP matrices <gx1> and <gx2> using
- *            <esl_FCompare()> and relative epsilon <tolerance>. If any
+ *            <esl_FCompare_old()> and relative epsilon <tolerance>. If any
  *            value pairs differ by more than the acceptable <tolerance>
  *            return <eslFAIL>.  If all value pairs are identical within
  *            tolerance, return <eslOK>. 
@@ -231,12 +231,12 @@ p7_gmx_Compare(P7_GMX *gx1, P7_GMX *gx2, float tolerance)
   {
       for (k = 1; k <= gx1->M; k++) /* k=0 is a boundary; doesn't need to be checked */
       {
-		  if (esl_FCompare(gx1->dp[i][k * p7G_NSCELLS + p7G_M],  gx2->dp[i][k * p7G_NSCELLS + p7G_M], tolerance) != eslOK) return eslFAIL;
-		  if (esl_FCompare(gx1->dp[i][k * p7G_NSCELLS + p7G_I],  gx2->dp[i][k * p7G_NSCELLS + p7G_I], tolerance) != eslOK) return eslFAIL;
-		  if (esl_FCompare(gx1->dp[i][k * p7G_NSCELLS + p7G_D],  gx2->dp[i][k * p7G_NSCELLS + p7G_D], tolerance) != eslOK) return eslFAIL;
+        if (esl_FCompare_old(gx1->dp[i][k * p7G_NSCELLS + p7G_M],  gx2->dp[i][k * p7G_NSCELLS + p7G_M], tolerance) != eslOK) return eslFAIL;
+        if (esl_FCompare_old(gx1->dp[i][k * p7G_NSCELLS + p7G_I],  gx2->dp[i][k * p7G_NSCELLS + p7G_I], tolerance) != eslOK) return eslFAIL;
+        if (esl_FCompare_old(gx1->dp[i][k * p7G_NSCELLS + p7G_D],  gx2->dp[i][k * p7G_NSCELLS + p7G_D], tolerance) != eslOK) return eslFAIL;
       }
       for (x = 0; x < p7G_NXCELLS; x++)
-	if (esl_FCompare(gx1->xmx[i * p7G_NXCELLS + x], gx2->xmx[i * p7G_NXCELLS + x], tolerance) != eslOK) return eslFAIL;
+	if (esl_FCompare_old(gx1->xmx[i * p7G_NXCELLS + x], gx2->xmx[i * p7G_NXCELLS + x], tolerance) != eslOK) return eslFAIL;
   }
   return eslOK;	
 }
@@ -400,7 +400,9 @@ utest_GrowTo(void)
 {
   P7_GMX *gx = NULL;
   int     M, L;
+#if !defined(eslENABLE_ASAN) && !defined(eslENABLE_TSAN)
   int64_t nbytes;
+#endif
 
   M = 20;    L = 20;    gx= p7_gmx_Create(M, L);  gmx_testpattern(gx, M, L);
   M = 40;    L = 20;    p7_gmx_GrowTo(gx, M, L);  gmx_testpattern(gx, M, L);  /* grow in M, not L */
@@ -415,7 +417,8 @@ utest_GrowTo(void)
   M = 179;   L = 55;    p7_gmx_GrowTo(gx, M, L);  gmx_testpattern(gx, M, L);
   M = 87;    L = 57;    p7_gmx_GrowTo(gx, M, L);  gmx_testpattern(gx, M, L);
 
-  /* and this exercises iss#176. Only do this on 64-bit systems, and only if a large alloc is possible (we need 8.6G to exercise the bug!) */
+  /* and this exercises iss#176. Only do this if a large alloc is possible (we need 8.6G to exercise the bug!) */
+#if !defined(eslENABLE_ASAN) && !defined(eslENABLE_TSAN)  // I've seen asan/tsan fail here in a Linux VM just because of the large alloc
   M = 71582; L = 10000;
   nbytes = (int64_t) (M+1) * (int64_t) (L+1) * (int64_t) p7G_NSCELLS * (int64_t) sizeof(float);
   if ( nbytes < SIZE_MAX / 2)
@@ -427,6 +430,7 @@ utest_GrowTo(void)
 	  p7_gmx_GrowTo(gx, M, L);  gmx_testpattern(gx, M, L);
 	}
     }
+#endif
 
   p7_gmx_Destroy(gx);
 }
@@ -464,7 +468,7 @@ utest_Compare(ESL_RANDOMNESS *r, P7_PROFILE *gm, P7_BG *bg, int L, float toleran
   gcc -o p7_gmx_utest -msse2 -g -Wall -I. -L. -I../easel -L../easel -Dp7GMX_TESTDRIVE p7_gmx.c -lhmmer -leasel -lm
   ./p7_gmx_utest
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>
 #include <math.h>
