@@ -4,7 +4,7 @@
  *           3) Test Driver
  * NPC 2/13/19 [The soothing whir of the air filter]
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -84,7 +84,9 @@ ERROR:
  */
 
 extern void p7_hit_Destroy(P7_HIT *the_hit){
-  if (the_hit == NULL){
+  int i;
+  if (the_hit == NULL)
+  {
     return;
   }
 
@@ -104,7 +106,7 @@ extern void p7_hit_Destroy(P7_HIT *the_hit){
 
   // need to do this manually rather than calling p7_domain_Destroy because we have an array of hits as one record
   if(the_hit->dcl !=NULL){
-    for(int i = 0; i < the_hit->ndom; i++){
+    for(i = 0; i < the_hit->ndom; i++){
       if(the_hit->dcl[i].scores_per_pos != NULL){
         free(the_hit->dcl[i].scores_per_pos);
       }
@@ -123,6 +125,65 @@ extern void p7_hit_Destroy(P7_HIT *the_hit){
   return;
 }
 
+/* Function: p7_hit_Copy()
+ * Synopsis: Copy a hit.
+ *
+ * Purpose:  Copies hit <src> to hit <dst>, where <dst> has already been 
+ *           allocated.
+ * 
+ * Returns:   <eslOK> on success.
+ * 
+ * Throws:    <eslEMEM> on allocation error.
+ */
+extern int p7_hit_Copy(const P7_HIT *src, P7_HIT *dst){
+  int i;
+  int status;
+  char *name = NULL, *acc = NULL, *desc = NULL;
+  P7_DOMAIN *dcl = NULL;
+  
+  // make all failible allocations to local variables first
+  if (src->name != NULL) {
+    if ((status = esl_strdup(src->name, -1, &name)) != eslOK) goto ERROR;
+  }
+  if (src->acc != NULL) {
+    if ((status = esl_strdup(src->acc, -1, &acc)) != eslOK) goto ERROR;
+  }
+  if (src->desc != NULL) {
+    if ((status = esl_strdup(src->desc, -1, &desc)) != eslOK) goto ERROR;
+  }
+  if (src->dcl != NULL) {
+    ESL_ALLOC(dcl, sizeof(P7_DOMAIN) * src->ndom);
+    for (i = 0; i < src->ndom; i++) {
+      dcl[i].ad = NULL;
+      dcl[i].scores_per_pos = NULL;
+    }
+    for (i = 0; i < src->ndom; i++) {
+      if ((status = p7_domain_Copy(&(src->dcl[i]), &(dcl[i]))) != eslOK) goto ERROR;
+    }
+  }
+  
+  // update <dst> after all allocations succeeded
+  memcpy(dst, src, sizeof(P7_HIT));
+  dst->name = name;
+  dst->acc = acc;
+  dst->desc = desc;
+  dst->dcl = dcl;
+  return eslOK;
+    
+ERROR:
+  free(name);
+  free(acc);
+  free(desc);
+  if (dcl != NULL) {
+    for (i = 0; i < src->ndom; i++) {
+      free(dcl[i].ad);
+      free(dcl[i].scores_per_pos);
+    }
+    free(dcl);
+  }
+  return status;
+}
+
 
 /* Function:  p7_HIT_Serialize
  * Synopsis:  Serializes a P7_HIT object into a stream of bytes
@@ -164,7 +225,7 @@ extern int p7_hit_Serialize(const P7_HIT *obj, uint8_t **buf, uint32_t *n, uint3
   uint32_t network_32bit; // hold 32-bit fields after conversion to network order
   uint64_t network_64bit; // hold 64-bit fields after conversion to network order
   uint8_t presence_flags = 0;
-
+  int i;
 
   // check to make sure we were passed a valid pointer 
   if(obj == NULL || buf == NULL || n == NULL || ((*buf == NULL) && ((*n != 0) || (*nalloc != 0)))) { 
@@ -345,7 +406,7 @@ extern int p7_hit_Serialize(const P7_HIT *obj, uint8_t **buf, uint32_t *n, uint3
 
   *n = ptr - *buf;  // update n to point to end of serialized region
 
-  for(int i = 0; i < obj->ndom; i++){
+  for(i = 0; i < obj->ndom; i++){
     status = p7_domain_Serialize(&(obj->dcl[i]), buf, n, nalloc);
     if(status != eslOK){
       return status;
@@ -384,10 +445,12 @@ extern int p7_hit_Deserialize(const uint8_t *buf, uint32_t *n, P7_HIT *ret_obj){
   uint32_t host_32bit; //variable to hold 64-bit values after conversion to host order
   uint32_t obj_size; // How much space does the variable-length portion of the serialized object take up?
   int status, string_length; 
-  uint8_t presence_flags; 
-  if(ret_obj == NULL || buf == NULL || n == NULL){
+  uint8_t presence_flags;
+  int i;
+  if (ret_obj == NULL || buf == NULL || n == NULL)
+  {
     return eslEINVAL;
-  }   
+  }
 
   ptr = (uint8_t *) buf + *n;
   
@@ -563,7 +626,7 @@ extern int p7_hit_Deserialize(const uint8_t *buf, uint32_t *n, P7_HIT *ret_obj){
 
   *n = ptr- buf; // reset n to point just past fixed-length fields
 
-  for(int i = 0; i < ret_obj->ndom; i++){
+  for(i = 0; i < ret_obj->ndom; i++){
     ret_obj->dcl[i].scores_per_pos = NULL;  // set internal pointers to known values so that domain_Deserialize does the right thing
     ret_obj->dcl[i].ad = NULL;
     int ret_code = p7_domain_Deserialize(buf, n, &(ret_obj->dcl[i]));
@@ -597,7 +660,7 @@ ERROR:
  * Throws:    Returns eslEMEM if unable to allocate or re-allocate memory. Returns eslEINVAL if ret_obj == NULL
  */
 extern int p7_hit_TestSample(ESL_RAND64 *rng, P7_HIT **ret_obj){
-  int status;
+  int status, i;
   int string_length;
   if(ret_obj == NULL){
     return eslEINVAL;
@@ -676,7 +739,7 @@ extern int p7_hit_TestSample(ESL_RAND64 *rng, P7_HIT **ret_obj){
 
   P7_DOMAIN **handle, *ptr; 
   handle = &ptr;
-  for(int i = 0; i < the_obj->ndom; i++){
+  for(i = 0; i < the_obj->ndom; i++){
     ptr = &(the_obj->dcl[i]);
     p7_domain_TestSample(rng, handle);
   }
@@ -705,7 +768,9 @@ ERROR:
  * Throws:    Nothing
  */ 
 extern int p7_hit_Compare(P7_HIT *first, P7_HIT *second, double atol, double rtol){
-  if(strcmp(first->name, second->name) != 0){
+  int i;
+  if (strcmp(first->name, second->name) != 0)
+  {
     return eslFAIL;
   }
 
@@ -733,31 +798,31 @@ extern int p7_hit_Compare(P7_HIT *first, P7_HIT *second, double atol, double rto
     return eslFAIL;
   }
 
-  if(esl_DCompareNew(first->sortkey, second->sortkey, atol, rtol) != eslOK){
+  if(esl_DCompare(first->sortkey, second->sortkey, atol, rtol) != eslOK){
     return eslFAIL;
   }
 
-  if(esl_FCompareNew(first->score, second->score, (float) atol, (float) rtol) != eslOK){
+  if(esl_FCompare(first->score, second->score, (float) atol, (float) rtol) != eslOK){
     return eslFAIL;
   }
 
-  if(esl_FCompareNew(first->pre_score, second->pre_score, (float) atol, (float) rtol) != eslOK){
+  if(esl_FCompare(first->pre_score, second->pre_score, (float) atol, (float) rtol) != eslOK){
     return eslFAIL;
   }
 
-  if(esl_FCompareNew(first->sum_score, second->sum_score, (float) atol, (float) rtol) != eslOK){
+  if(esl_FCompare(first->sum_score, second->sum_score, (float) atol, (float) rtol) != eslOK){
     return eslFAIL;
   }
 
-  if(esl_DCompareNew(first->lnP, second->lnP, atol, rtol) != eslOK){
+  if(esl_DCompare(first->lnP, second->lnP, atol, rtol) != eslOK){
     return eslFAIL;
   }
 
- if(esl_DCompareNew(first->pre_lnP, second->pre_lnP, atol, rtol) != eslOK){
+ if(esl_DCompare(first->pre_lnP, second->pre_lnP, atol, rtol) != eslOK){
     return eslFAIL;
   }
 
- if(esl_DCompareNew(first->sum_lnP, second->sum_lnP, atol, rtol) != eslOK){
+ if(esl_DCompare(first->sum_lnP, second->sum_lnP, atol, rtol) != eslOK){
     return eslFAIL;
   }
 
@@ -809,7 +874,7 @@ extern int p7_hit_Compare(P7_HIT *first, P7_HIT *second, double atol, double rto
     return eslFAIL;
   }
 
-  for(int i = 0; i < first->ndom; i++){
+  for(i = 0; i < first->ndom; i++){
     if(p7_domain_Compare(&(first->dcl[i]), &(second->dcl[i]), atol, rtol) != eslOK){
       return eslFAIL;
     }
@@ -952,7 +1017,7 @@ static void utest_Deserialize_error_conditions(){
     esl_fatal(msg);
   }
   //printf("Test 3 passed\n");
-
+  free(buf);
   p7_hit_Destroy(deserial);
   p7_hit_Destroy(sampled);
   esl_rand64_Destroy(rng);
@@ -1003,6 +1068,8 @@ static void utest_Serialize(int ntrials){
     if(p7_hit_Compare(serial[i], deserial, 1e-4, 1e-4) != eslOK){ // deserialized structure didn't match serialized
       esl_fatal(msg);
     }
+    p7_hit_Destroy(deserial);
+    deserial = p7_hit_Create_empty();
 
   }
   // haven't failed yet, so we've succeeded.  Clean up and exit
@@ -1013,7 +1080,7 @@ static void utest_Serialize(int ntrials){
   }
   free(serial);
   p7_hit_Destroy(deserial);
-
+  esl_rand64_Destroy(rng);
   return;
 
   ERROR:
