@@ -7,7 +7,7 @@
  * 3) Test driver
 */
 
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -201,7 +201,9 @@ extern int p7_hmmd_search_stats_Serialize(const HMMD_SEARCH_STATS *obj, uint8_t
     ptr += sizeof(uint64_t);
   }
   else{
-    for(int i = 0; i < obj->nhits; i++){
+    int i;
+    for (i = 0; i < obj->nhits; i++)
+    {
       network_64bit = esl_hton64(obj->hit_offsets[i]);
       memcpy((void *) ptr, (void *) &network_64bit, sizeof(uint64_t));  
       ptr += sizeof(uint64_t);
@@ -374,7 +376,9 @@ extern int p7_hmmd_search_stats_Deserialize(const uint8_t *buf, uint32_t *n, HMM
     }
 
     ret_obj->hit_offsets[0] = esl_ntoh64(network_64bit); //already have the first offset read out of the buffer
-    for(int i = 1; i < ret_obj->nhits; i++){
+    int i;
+    for (i = 1; i < ret_obj->nhits; i++)
+    {
       memcpy(&network_64bit, ptr, sizeof(uint64_t));
       ptr += sizeof(uint64_t);
       ret_obj->hit_offsets[i] = esl_ntoh64(network_64bit);
@@ -476,7 +480,9 @@ static int hmmd_search_stats_Same(const HMMD_SEARCH_STATS *first, const HMMD_SEA
   }
 
   if(first->hit_offsets != NULL){ // both must have a hit_offsets array, since we'd already have failed if only one did
-    for(int i = 0; i < first->nhits; i++){ // we've already checked that both objects have the same value for nhits
+    int i;
+    for (i = 0; i < first->nhits; i++)
+    { // we've already checked that both objects have the same value for nhits
       if(first->hit_offsets[i] != second->hit_offsets[i]){
         return eslFAIL;
       }
