@@ -3,8 +3,8 @@
  * EPN, Thu Jul  7 13:08:55 2011
  * SRE, Fri Oct 17 11:24:26 2008 [Janelia] (hmmpress.c)
  */
-#include "esl_config.h"
-#include "p7_config.h"
+#include <esl_config.h>
+#include <p7_config.h>
 #include "config.h"
 
 #include <stdio.h>
@@ -60,7 +60,6 @@ main(int argc, char **argv)
   struct dbfiles *dbf        = NULL;
   uint16_t        fh         = 0;
   int             ncm        = 0;
-  uint64_t        tot_clen   = 0;
   off_t           cm_offset  = 0;
   off_t           fp7_offset = 0;
   char            errbuf[eslERRBUFSIZE];
@@ -94,7 +93,6 @@ main(int argc, char **argv)
       }
       
       ncm++;
-      tot_clen += cm->clen;
 
       gm = p7_profile_Create(cm->fp7->M, abc);
       p7_ProfileConfig(cm->fp7, bg, gm, 400, p7_LOCAL);
@@ -147,6 +145,7 @@ main(int argc, char **argv)
   exit(0);
 
  ERROR:
+  fprintf(stderr, "%s\n", errbuf);
   close_dbfiles(dbf, status);
   p7_bg_Destroy(bg);
   cm_file_Close(cmfp);
