@@ -7,8 +7,8 @@
 #include <xmmintrin.h>
 #include <emmintrin.h>
 
-#include "esl_config.h"
-#include "p7_config.h"
+#include <esl_config.h>
+#include <p7_config.h>
 #include "config.h"
 
 #include "easel.h"
