@@ -5,8 +5,8 @@
  * Robert J. Klein
  * February 25, 2002
  */
-#include "esl_config.h"
-#include "p7_config.h"
+#include <esl_config.h>
+#include <p7_config.h>
 #include "config.h"
 
 #include <stdlib.h>
